function [A, X, iC]=TA_IC_affinities(I, affParam)
%
%[A, X, iC]=TA_IC_affinities(I)
%  
%  Computes the affinities and the observation vectors using the code of 
%  Timoty Cour and Jianbo Shi (see Jianbo Shi homepage)
%  The function returns also the feature vectors X and the contour map used
%  to compute the intervening contour for the affinities.
%  
%  Marco Andreetto, Caltech 2009
%

if nargin<2
  % parameter for the computation of the affinity matrix. The parameters
  % are: size of the neighborhood, sampling of the graphs edges, and
  % variance of the edge operator.
  affParam=struct('sampleRadius', 10, ...
                  'sample_rate', 1.0, ...
                  'edgeVariance', 0.1);
end

if ~isa(I, 'double')
  error('TA_IC_affinities: I must be of class double');
end

if max(max(max(I)))>1
  error('TA_IC_affinities: values in I must be in the 0-1 range');
end

% compute the affinities.
if (size(I, 3)>1), I=rgb2gray(I); end
[A, iC]=ICgraph(I*255, affParam);

% get the feature vectors
X=getFeatureVectors(I);

% since the code does not normalixe the countour map to 1 we do it.
iC=iC/(max(max(iC))+eps);

% AUTORIGHTS
% Copyright (C) 2008-2012 Marco Andreetto
%       
% This file is part of AB_SAMPLER.
% 
% AB_SAMPLER is free software; you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation; either version 2, or (at your option)
% any later version.
% 
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
% 
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software Foundation,
% Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
