function [A, X, iContours]=TA_Pb2_affinities(I, R)
%
%[A, X, iC]=TA_Pb2_affinities(I, R)
%  
%  TA_Pb_affinities computes the affinities and the observation vectors using
%  the 'Berkeley segmentation dataset and benchmarks'. See the link below
%  www.eecs.berkeley.edu/Research/Projects/CS/vision/grouping/segbench
%  
%  Marco Andreetto, Caltech 2009
% 

% =========================================================================
%  check if input image is valid (class double and 0-1 values)
% =========================================================================
if ~isa(I, 'double')
  error('TA_Pb2_affinities: I must be of class double');
end

if max(max(max(I)))>1
  error('TA_Pb2_affinities: values in I must be in the 0-1 range');
end

if (nargin<2), R=10; end;

% Intervening contour using mfm-pb. Code from Greg Mori's superpixels
[iContours, iPhase] = pbWrapper(I);
iContoursThick = pbThicken(iContours);

% pairs of pixels for which we compute the affinities
[ci, cj] = imnb(R, ones(rows(I), cols(I)));

% parameters for the IC 
si_pb_ic=0.2; % scaling of the IC value. Default value from the code
s = - 1 / (2 * si_pb_ic^2);
offset=0.05;

% affinities
A=exp( s*ic(iContoursThick, zeros(rows(I), cols(I)), ci, cj, []))+offset;
A=A./max(A); % normalize the maximum  value to 1

% construct the sparse matrix
A=csparse(ci, cj, A, rows(I)*cols(I));


% =========================================================================
%  get the feature vectors
% =========================================================================
X=getFeatureVectors(I);

% AUTORIGHTS
% Copyright (C) 2008-2012 Marco Andreetto
%       
% This file is part of AB_SAMPLER.
% 
% AB_SAMPLER is free software; you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation; either version 2, or (at your option)
% any later version.
% 
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
% 
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software Foundation,
% Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
