function [A, X, iContours]=TA_fixed_affinities(I, R)
%
%[A, X, iC]=TA_fixed_affinities(I, R)
%  
%  Given the image 'I'  computes the "fixed" affinities using a window of 
%  side 'R'. The fixed affinites consider only the relative position of the
%  pixels. If no value for 'R' is given the defualt 13 is used.
%  The function returns also the feature vectors 'X' and the contour map
%  'iC' used to  compute the affinities (all zeros input).
% 
%  Marco Andreetto, Caltech 2009
% 

% check default argument
if (nargin<2), R=11; end;

% pairs of pixels for which we compute the affinities
[ci, cj] = imnb(R, ones(rows(I), cols(I)));

% construct the sparse matrix
A=csparse(ci, cj, ones(length(ci), 1), rows(I)*cols(I));

% get the feature vectors
X=getFeatureVectors(I);

iContours=zeros(rows(I), cols(I));

% AUTORIGHTS
% Copyright (C) 2008-2012 Marco Andreetto
%       
% This file is part of AB_SAMPLER.
% 
% AB_SAMPLER is free software; you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation; either version 2, or (at your option)
% any later version.
% 
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
% 
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software Foundation,
% Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
