function [A, X, iC]=TA_lihi_affinities(I, R)
%
%TA_lihi_affinities
%  
%  [A, X]=TA_lihi_affinities(I, R), computes the affinities and the
%  observation vectors using the technique of Lihi. In particular it calls
%  'imAffSampler'.
%  

% by default we use a neighbor of dimension 11x11, the center of this
% square is the pixel we are considering.
if nargin==1, R=11; end

% Compute the affinities for the sampler. Use zero for the adaptive scale.
A=imAffSampler(I, R, 0.0);

% Get the feature vectors
X=getFeatureVectors(I);

% return a "null" contour map, i.e. an image with all the pixels to zero
iC=zeros(rows(I), cols(I));

% A sanity check on the consistency of the result.
if sum(sum(isnan(A)))>0 
  error('Found a NaN is the matrix A');
end

if sum(sum(isnan(X)))>0 
  error('Found a NaN is the matrix X');
end

% AUTORIGHTS
% Copyright (C) 2008-2012 Marco Andreetto
%       
% This file is part of AB_SAMPLER.
% 
% AB_SAMPLER is free software; you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation; either version 2, or (at your option)
% any later version.
% 
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
% 
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software Foundation,
% Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
