function ll_all=ab_likelihood_list(Cs, As, Xs, alpha, lambda, Ws, Vs, eta_s)
%
%AB_LIKELIHOOD_LIST
%
% Compute the log-likelihood for the given set of images (represented by
% As, and Ws). If multiple samples are given the the likelihood is computed
% for each of them.
%
% ll_all=ab_likelihood_list(Cs, As, Xs, alpha, lambda, Ws, Vs, eta_s)
% 

% We assume that all the images have the same number of samples
S=cols(Cs{1});
ll_all=zeros(1, S);

% cell array of empty matrices
si=xrepmat({[]}, 1, length(Cs));

for s=1:S
  
 % obtain the sample
 Ci=getSample(Cs, s); 
 [~, ll_all(s)]=ab_gibbs_sampling_list(As, Xs, alpha, 0, Ci, si, ...
                                          lambda, Ws, Vs, eta_s);
end


function Ci=getSample(Cs, s)

% number of images
M=length(Cs);
Ci=cell(1, M);

for m=1:M
  Ci{m}=Cs{m}(:, s);
end

% AUTORIGHTS
% Copyright (C) 2008-2012 Marco Andreetto
%       
% This file is part of AB_SAMPLER.
% 
% AB_SAMPLER is free software; you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation; either version 2, or (at your option)
% any later version.
% 
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
% 
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software Foundation,
% Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
