function outImage=blend_segments(probImage, K, inImage, colors)

% BLEND_SEGMENTS computes the blended segmentation mask 
% 

% by default we do not blend the image
if nargin<3, inImage=[]; end

% get the colors from the colorcube function 
if nargin<4, colors=seg_color(K); end

% check if segImage has value outside the range [1, K]
if size(probImage, 3)~=K, error('Wrong number of segments'); end

% dimension of the image
[M, N, K]=size(probImage);

% the three color channels
red=zeros(M, N);
green=zeros(M, N);
blue=zeros(M, N);

% iterate over all the segments
for h=1:K
  red=red+colors(h,1)*probImage(:,:,h);
  green=green+colors(h,2)*probImage(:,:,h);
  blue=blue+colors(h,3)*probImage(:,:,h);
end

% compose the outimage (range 0-1)
outImage=cat(3, red, green, blue);

% if we have an input image we 
if numel(inImage)~=0
  
  % we blend just the luminance component
  if size(inImage, 3)==3, inImage=rgb2gray(inImage); end

  % convert the original image in double between 0 and 1
  if isa(inImage, 'uint8'), inImage=double(inImage)/255; end

  outImage=0.5*outImage+0.5*xrepmat(inImage, [M, N, 3]);
end


% AUTORIGHTS
% Copyright (C) 2008-2012 Marco Andreetto
%       
% This file is part of AB_SAMPLER.
% 
% AB_SAMPLER is free software; you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation; either version 2, or (at your option)
% any later version.
% 
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
% 
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software Foundation,
% Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
