function classifyImages(ferns, expInfo, start, step)

% Given a forrest of ferns classify all the pixels in all the images.
K=expInfo.K;

if nargin<3
  start=1;
  step=1;
end

for h=1:length(expInfo.data_file_info(start:step:end))
  I=im2double(imread(expInfo.data_file_info{h}.original_name));
  [segImageMAP, probImage]=classifyPatches(I, ferns); %#ok<ASGLU>

  % scale and exp the probabilities
  probImage=probImage-repmat(max(probImage, [], 3), [1 1 K]);
  probImage=exp(probImage);
  probImage=probImage./repmat(sum(probImage, 3), [1, 1, K]);
  
  save(sprintf('%s/seg_fern_%04d.mat', expInfo.destDir, h), ...
    'segImageMAP', 'probImage');
  putDot(h);
end
disp(' ');


function [segImageMAP, probImage]=classifyPatches(I, ferns)

% collect all the patches
[R, L]=getPatchDim;

% create the patches and collect their corresponding labels.
features=[];
for c=1:size(I, 3)
  p=im2col(addborder(I(:,:,c), R, R, -1), [L L], 'sliding');
  features=cat(1, features, p);
end

[segImageMAP, probImage]=fernsClfApply(features', ferns);
segImageMAP=reshape(segImageMAP, rows(I), cols(I));
probImage=reshape(probImage, rows(I), cols(I), cols(probImage));


function [R, L]=getPatchDim

R=6;
L=2*R+1;


% AUTORIGHTS
% Copyright (C) 2008-2012 Marco Andreetto
%       
% This file is part of AB_SAMPLER.
% 
% AB_SAMPLER is free software; you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation; either version 2, or (at your option)
% any later version.
% 
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
% 
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software Foundation,
% Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
