function [pr, rc, ct, labels]=collectionResults(segMasks, collectionList)
% 
% [pr, rc, ct]=collectionResults(segMasks, collectionList)
%
% This function compute the precision/recall and detection/false allarm
% rates for the images described in 'collectionList'. If 'collectionList' is a 
% string it specifies the directory with ground truth mat files. If it is a
% cell array it specifies the xml files with all the information about the
% images. The 'segMasks' is a cell array with the image segmentation.
%

%
% Collect all the MAT file names 
%

if isa(collectionList, 'char')
  % we read the ground truth from the specified directory.
  matFileNames=dir([collectionDir, '/*.png.gt_seg.mat']);
  matFileNames=strcat([collectionDir, '/'], {matFileNames.name});
else
  % we have a list of xml files. We extract all the grounf truth file
  matFileNames=cell(1, length(collectionList));
  for h=1:length(collectionList)
    imageInfo=xml_load(collectionList{h});
    matFileNames{h}=imageInfo.ground_truth_name;
  end
  
end 

NF=length(matFileNames);

% sanity check
if NF~=length(segMasks), error('Wrong number of images/segmentations'); end

% load all the ground truth masks and obtain a list of unique labels
gtMasks=cell(1, NF);
labels=[];

baseDir='/home/marco/research/projects/AB_Clustering/';
load([baseDir, '/testing/msrcGT.mat'], 'class_labels');

for h=1:NF
  load(matFileNames{h}, 'gt_seg'); % ground truth segmentation
  gtMasks{h}=gt_seg;
  labels=cat(1, labels, unique(gtMasks{h}(:)));
end
labels=unique(labels);

% iterate over all the segmentation and get the largest label index
Ks=0;
for h=1:length(segMasks), Ks=max(Ks, max(max(segMasks{h}))); end

% we have as many columns as labels and Ks rows. See wikipedia for the
% convention on rows and columns. 
% (http://en.wikipedia.org/wiki/Precision_and_recall)
ct=zeros(Ks, length(labels));

% iterate over all the segmentation and compute the confusion table
for h=1:NF
  
  % iterate over all the labels
  for k=1:cols(ct)
    idx=(gtMasks{h}==labels(k));
    if sum(sum(idx))==0, continue; end    
    ct(:, k)=ct(:, k)+hist(segMasks{h}(idx), 1:Ks)';
  end
  
end

% sort the row so that the first column is in descending order
[~, idx]=sort(ct(:, 1), 'descend');
ct_sorted=ct(idx,:);

% find which segment captures faces.
pr=ct_sorted(1, 1)/sum(ct_sorted(1, :));
rc=ct_sorted(1, 1)/sum(ct_sorted(:, 1));

% AUTORIGHTS
% Copyright (C) 2008-2012 Marco Andreetto
%       
% This file is part of AB_SAMPLER.
% 
% AB_SAMPLER is free software; you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation; either version 2, or (at your option)
% any later version.
% 
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
% 
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software Foundation,
% Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
