function [outImage, colors]=color_segments(segImage, K, inImage, colors)
% COLOR_SEGMENT assigns colors to the given segmentation mask

% if the number of segment is negative than we use the gray color for the
% background. We also change the sign of K
if (K<0)
  useBackground=true;
  K=-K;
else
  useBackground=false;
end

% by default we do not blend the image
if nargin<3, inImage=[]; end

% get the colors from the colorcube function 
if nargin<4, colors=seg_color(K, useBackground); end

% check if segImage has value outside the range [1, K]
if any( (segImage<=0) | (segImage>K) ), error('Invalid segment label'); end

% dimension of the image
[M, N]=size(segImage);

% the three color channels
red=zeros(M, N);
green=zeros(M, N);
blue=zeros(M, N);

% iterate over all the segments
for h=1:K
  % the h-th segment 
  idx=segImage==h;

  red(idx)=colors(h,1);
  green(idx)=colors(h,2);
  blue(idx)=colors(h,3);
end

% compose the outimage (range 0-1)
outImage=cat(3, red, green, blue);

% if we have an input image we 
if numel(inImage)~=0
  
  % we blend just the luminance component
  if size(inImage, 3)==3, inImage=rgb2gray(inImage); end

  % convert the original image in double between 0 and 1
  inImage=im2double(inImage);

  outImage=0.5*outImage+0.5*xrepmat(inImage, [M, N, 3]);
end

% AUTORIGHTS
% Copyright (C) 2008-2012 Marco Andreetto
%       
% This file is part of AB_SAMPLER.
% 
% AB_SAMPLER is free software; you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation; either version 2, or (at your option)
% any later version.
% 
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
% 
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software Foundation,
% Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
