function [texture_words, mu, L, errlog]=compFilterBankCenters(xmlFileNames, ncenters, normalize)
%
% Construct the sift_words using kmeans. ncenters is the number of words.
%

% normalize by default 
if nargin <3, normalize=true; end

% dimension of the feature space
Dim=17; % Criminisi et al.

% shuffle them
idx=randperm(length(xmlFileNames));
xmlFileNames=xmlFileNames(idx);

% collect data

% number of datapoints used to compute the kmeans centers
ndesc=ncenters*10000;

% allocate the memory for the descriptors
desc=zeros(ndesc, Dim);

% fake centers
sw=zeros(Dim, Dim);

% starting center
idx_start=1;

disp('Collect descriptors');
for h=1:length(xmlFileNames);

  % compute the descriptor *it should be cached in a  MAT file).
  [~, ~, ~, fbDesc]=xmlLoadPatchFilters(xmlFileNames{h}, 4, sw, [], []);
  
  % add the descriptor to the data
  idx_stop=idx_start+rows(fbDesc)-1;
  if idx_stop>rows(desc)
    % we have an overflow for the number of descriptor.
    % take just the required number.
    idx_stop=rows(desc);
    len=idx_stop-idx_start+1;
    fbDesc=fbDesc(1:len, :);
  end
  desc(idx_start:idx_stop, :)=fbDesc;
  
  % move to the next batch.
  idx_start=idx_stop+1;
  
  % if we have enough data we exit the cycle
  if idx_start>ndesc, break; end
  
  putDot(h);
end
disp(' ');

if (idx_stop<ndesc)
  disp('Warning: Too few descriptor');
  desc((idx_stop+1):end, :)=[];
  ndesc=rows(desc);
end  


% normalize the points in space if necessary
if normalize
  % centering
  mu=mean(desc);
  desc=desc-repmat(mu, rows(desc), 1);

  % normalization
  L=chol(cov(desc));
  desc=(inv(L')*desc')';

  disp('Normalizing the feature vector');
else
  
  L=[];
  mu=[];

  disp('Using raw filter response');
end



% ========================================================================
% run kmeans
% ========================================================================

OPTIONS(1) = 0;
OPTIONS(2) = 10^-4;
OPTIONS(3) = 10^-4;
OPTIONS(5) = 1; % reinitialize centers as random perm of data
OPTIONS(14) = 1000;

idx=randperm(rows(desc));

disp('Run kmeans clustering');
centers=desc(idx(1:ncenters), :);
tic;
[texture_words, ~, ~, errlog]=new_kmeans(centers, desc, OPTIONS);
elapsed_time=toc;

plot(errlog); grid on;

% AUTORIGHTS
% Copyright (C) 2008-2012 Marco Andreetto
%       
% This file is part of AB_SAMPLER.
% 
% AB_SAMPLER is free software; you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation; either version 2, or (at your option)
% any later version.
% 
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
% 
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software Foundation,
% Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
