function [spI, spProb]=compSPLabel(SP, I, prob)
%
% Compute the most "important" label for a superpixel. The most important
% label is defined as the most frequent label among the pixels of a
% superpixel. 
%

K=max(max(I));
nSP=max(max(SP)); % number of labels in the superpixel segmentation

spI=zeros(size(I));

if (nargin>2)
  prob=reshape(prob, numel(I), size(prob, 3));
  spProb=zeros(size(prob));
end

for s=1:nSP
  % indeces of the superpixel 's'
  idx=SP==s;
  
  % compute the histogram of value in the current superpixel 
  % and get the most popular label
  [v, w]=hist(I(idx), 1:K);
  [~, l]=max(v);
  
  % assign it to the output label
  spI(idx)=w(l);
  
  if nargin>2
    avgP=mean(prob(idx, :));
    spProb(idx, :)=repmat(avgP, sum(sum(idx)), 1);
  end
  
end

if nargin>2
  spProb=reshape(spProb, rows(I), cols(I), []);
end
% AUTORIGHTS
% Copyright (C) 2008-2012 Marco Andreetto
%       
% This file is part of AB_SAMPLER.
% 
% AB_SAMPLER is free software; you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation; either version 2, or (at your option)
% any later version.
% 
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
% 
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software Foundation,
% Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
