function [sift_words, errlog]=compSiftCenters(xmlFileNames, ncenters)
%
% Construct the sift_words using kmeans. ncenters is the number of words.
%

% shuffle them
idx=randperm(length(xmlFileNames));
xmlFileNames=xmlFileNames(idx);

% collect data

% number of datapoints used to compute the kmeans centers
ndesc=ncenters*10000;

% allocate the memory for the descriptors
desc=zeros(ndesc, 128);

% fake centers
sw=zeros(ncenters, 128);

% starting center
idx_start=1;


for h=1:length(xmlFileNames);

  % compute the descriptor *it should be cached in a  MAT file).
  [~, ~, ~, siftDesc]=xmlLoadPatchSift(xmlFileNames{h}, 4, sw, true);
  
  % add the descriptor to the data
  idx_stop=idx_start+rows(siftDesc)-1;
  if idx_stop>rows(desc)
    % we have an overflow for the number of descriptor.
    % take just the required number.
    idx_stop=rows(desc);
    len=idx_stop-idx_start+1;
    siftDesc=siftDesc(1:len, :);
  end
  desc(idx_start:idx_stop, :)=siftDesc;
  
  % move to the next batch.
  idx_start=idx_stop+1;
  
  % if we have enough data we exit the cycle
  if idx_start>ndesc, break; end
  
  putDot(h);
end
disp(' ');

if (idx_stop<ndesc)
  disp('Warning: Too few descriptor');
  desc((idx_stop+1):end, :)=[];
  ndesc=rows(desc);
end

% load tmp_msrc_v2.mat

%
% run kmeans
%

OPTIONS(1) = 0;
OPTIONS(2) = 10^-4;
OPTIONS(3) = 10^-4;
OPTIONS(5) = 1; % reinitialize centers as random perm of data
OPTIONS(14) = 200;

idx=randperm(rows(desc));
disp('Start kmeans');

centers=desc(idx(1:ncenters), :);
[sift_words, ~, ~, errlog]=new_kmeans(centers, desc, OPTIONS);

plot(errlog); grid on;

% AUTORIGHTS
% Copyright (C) 2008-2012 Marco Andreetto
%       
% This file is part of AB_SAMPLER.
% 
% AB_SAMPLER is free software; you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation; either version 2, or (at your option)
% any later version.
% 
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
% 
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software Foundation,
% Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
