function desc=compSiftDesc(I, frames)

% make sure the image is between 0 and 1
if max(max(max(I)))>1
  error('Image should be between 0 and 1');
end

% pad the frame with a constant orientation
sift_frames=[frames zeros(rows(frames), 1)];
sift_frames(:, 3)=sift_frames(:, 3)/(1.5*4);

% convert the image to grayscale if necessary
if size(I, 3), I=rgb2gray(I); end

% save the image
imwrite(I, '/tmp/marco_image.pgm');

% save the frames
fid=fopen('/tmp/marco_image.key', 'w');
fprintf(fid, '%f %f %f %f\n', sift_frames');
fclose(fid);

% run the command
command=['/home/marco/research/libraries/Vedaldi/siftpp/sift ', ...
  '--keypoints=/tmp/marco_image.key --stable-order ', ...
  '--output=/tmp/marco_image.desc /tmp/marco_image.pgm'];

[s,w]=system(command);
if (s~=0), error(w); end;

% read back the descriptors
data=textread('/tmp/marco_image.desc');
desc=data(:, 5:end);

% check that the order has not changed
if sum(data(:,1:4)~=sift_frames)>0
  error('No stable order');
end

% at this point we should remove all the patches that have a low
% variability.

% iterate over all the frames
for l=1:rows(frames)

  % extract the patch
  S=frames(l, 3);
  idx_ix=frames(l, 1)+(-S:S);
  idx_iy=frames(l, 2)+(-S:S);
  
  % clip the value if outside the image
  idx_ix(idx_ix<1 | idx_ix>cols(I))=[];
  idx_iy(idx_iy<1 | idx_iy>rows(I))=[];
  
  patch=I(idx_iy, idx_ix);

  % check that the standard deviation is not too small
  if (std(patch(:), 1)<(1/255))
    desc(l, :)=-ones(1, 128);
  end
end

% AUTORIGHTS
% Copyright (C) 2008-2012 Marco Andreetto
%       
% This file is part of AB_SAMPLER.
% 
% AB_SAMPLER is free software; you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation; either version 2, or (at your option)
% any later version.
% 
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
% 
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software Foundation,
% Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
