function tree=compSiftTree(xmlFileNames, ncenters)
%
% Construct the sift_words using kmeans. ncenters is the number of words.
%

% shuffle them
idx=randperm(length(xmlFileNames));
xmlFileNames=xmlFileNames(idx);

% collect data

% number of datapoints used to compute the kmeans centers
ndesc=ncenters*500;

% allocate the memory for the descriptors
desc=uint8(zeros(128, ndesc));

% fake centers
sw=zeros(128, 128);

% starting center
idx_start=1;


for h=1:length(xmlFileNames);

  % compute the descriptor (it should be cached in a  MAT file).
  [W, ix, iy, siftDesc]=xmlLoadPatchSift(xmlFileNames{h}, 4, sw);
  
  % add the descriptor to the data
  idx_stop=idx_start+rows(siftDesc)-1;
  if idx_stop>ndesc
    % we have an overflow for the number of descriptor.
    % take just the required number.
    idx_stop=ndesc;
    len=idx_stop-idx_start+1;
    siftDesc=siftDesc(1:len, :);
  end
  desc(:, idx_start:idx_stop)=siftDesc';
  
  % move to the next batch.
  idx_start=idx_stop+1;
  
  % if we have enough data we exit the cycle
  if idx_start>ndesc, break; end
  
  putDot(h);
end
disp(' ');

if (idx_start<=ndesc)
  disp('Warning: coming short of descriptors');
  desc(:, idx_start:end)=[];
  ndesc=idx_start-1;
end

disp(['Total number of descriptors for the hierarchical kmeans: ', ...
  num2str(ndesc)]);


%
% run hikmeans from vl_feat.
%

disp(['Start hierarchical kmeans with ', num2str(ncenters)]);
tree_K=10; % number of branches 

tic;
[tree, asgn] = vl_hikmeans(desc, tree_K, ncenters);
ttt=toc;
disp(['Total time for hierarchical kmeans: ', num2str(ncenters)]);

% AUTORIGHTS
% Copyright (C) 2008-2012 Marco Andreetto
%       
% This file is part of AB_SAMPLER.
% 
% AB_SAMPLER is free software; you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation; either version 2, or (at your option)
% any later version.
% 
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
% 
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software Foundation,
% Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
