/* AUTORIGHTS
Copyright (C) 2008-2012 Marco Andreetto
      
This file is part of AB_SAMPLER.

AB_SAMPLER is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2, or (at your option)
any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software Foundation,
Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
*/

#include <iostream>
#include <fstream>
#include <vector>
#include <iterator>
#include <cmath>

#include <boost/lexical_cast.hpp>

#include "mex.h"


using namespace std;
using namespace boost;

// aliases for the input/output arguments parameters

#define iW (in[0])
#define iC (in[1])
#define iV (in[2])
#define iK (in[3])

#define oB (out[0])


//
// The inputs are the responsability matrix R and the word vector W
//


void mexFunction(int n_out, mxArray *out[],
                 int n_in, const mxArray *in[])
{ 
  //
  // Check the inputs and the output arguments   
  //
  
  if (n_in!=4)
    mexErrMsgTxt("Four inputs required");
  
  if (n_out!=1)
    mexErrMsgTxt("One output required");
  
  // first we check for compatible dimension
  unsigned NI=mxGetM(iW)*mxGetN(iW);
  if (NI != mxGetM(iC)*mxGetN(iC))
    mexErrMsgTxt("Incompatible dimensions of visual words and samples");
  
  // get the number of visual words and the number of topics
  unsigned V=static_cast<unsigned>(mxGetScalar(iV));
  unsigned K=static_cast<unsigned>(mxGetScalar(iK));
  
  // create the output matrix and fill it with zeros;
  oB=mxCreateDoubleMatrix(K, V, mxREAL);
  double *betas=mxGetPr(oB);
  fill(betas, betas+(K*V), 0.0f);
  
  // iterate over all the images
  mxArray *Ci, *Wi;
  for(unsigned ni=0; ni!=NI; ++ni){
    
    // extract the words and label for this document
    Ci=mxGetCell(iC, ni); // mxArray pointer for the labels
    Wi=mxGetCell(iW, ni); // mxArray pointer for the visual word histograms
    
    // iterate over all the superpixels
    unsigned Nsp=mxGetM(Ci)*mxGetN(Ci); // number of superpixels
    
    // check if the dimensions of Wi is compatible
    if ( mxGetM(Wi) != V)
      mexErrMsgTxt("Wrong number of visual words.");

    if ( mxGetN(Wi) != Nsp)
      mexErrMsgTxt("Wrong number of superpixel.");

    // iterate over all the superpixels for image h
    double *wi=mxGetPr(Wi); // begin of the visual words histogram
    for(double *ci=mxGetPr(Ci); ci != mxGetPr(Ci)+Nsp; ++ci) {
      unsigned k=(static_cast<unsigned>(*ci))-1; 
      
      // iterate over all the visual words in the superpixel
      for(unsigned h=0; h<V; ++h, ++wi)
        betas[h*K+k]+=*wi; // add the content of this histogram
      
    } // end of the visual word table scanning.
  } // end of the iteration over all the images in the collection
}
