function vi=compVarInfo(cf_table)

% vi=compVarInfo(cf_table)
%   
%   given the confusion table computes the variation of information as
%   defined in [1]. 
%
%
%  [1] M. Meila "Comparing clusterings" COLT 2003
%

K1=rows(cf_table); % number of segments in the results
K2=cols(cf_table); % number of segments in the ground truth

% we may have problems if we have zero entries in the cf_table. We add a
% very small value to avoid this.
cf_table=cf_table+eps;

% total number of observation in the dataset.
N=sum(sum(cf_table));

% join empirical distribution
Prg=cf_table/N;

% compute the marginal distributions and the entropy for each segmentation
Pr=row_sum(Prg);  % segmentatio results
Hr=-sum(Pr.*log2(Pr));

Pg=col_sum(Prg);  % ground truth segmentation
Hg=-sum(Pg.*log2(Pg));

% compute the mutual information between the segmentation result and the
% ground truth segmentation.
Irg=sum(sum(Prg.*(log2(Prg./(repmat(Pr, 1, K2) .* repmat(Pg, K1, 1))))));

% variation of information
vi=(Hr+Hg-2*Irg);
vi=vi/log2(N);

% AUTORIGHTS
% Copyright (C) 2008-2012 Marco Andreetto
%       
% This file is part of AB_SAMPLER.
% 
% AB_SAMPLER is free software; you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation; either version 2, or (at your option)
% any later version.
% 
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
% 
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software Foundation,
% Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
