function xmlFiles=create_xml_file_info(datasetName, datasetDir, imageFormat)
%
% Construct the xml files for the files in 'datasetDir'. 
%

if (nargin<2)
  datasetDir='/common/marco/clustering/datasets/egret_collection/'; 
end
if (nargin<3), imageFormat='png'; end

% obtain all the originals
orFiles=getAllFilesInDir(datasetDir, ['*.', imageFormat]);

% dataset name
s.datasetName=datasetName;

xmlFiles=cell(1, length(orFiles));

force=false;

% construct the xmlFiles
for h=1:length(orFiles)
  s.original_name=orFiles{h};
  s.imageFormat=imageFormat;
  
  I=imread(s.original_name);
  s.width=cols(I);
  s.height=rows(I);
  s.isRGB=(size(I, 3)==3);
  
  s.xml_name=[s.original_name, '.xml'];
  
  % this file should be present as ground truth
  ground_truth_name=[s.original_name, '.gt_seg.mat'];
  if exist(ground_truth_name, 'file')
    s.ground_truth_name=ground_truth_name;
  else
    s.ground_truth_name=''; % no file name
  end
  
  if (~force) && exist(s.xml_name, 'file')
    disp('There are already some XML files for this dataset!!!');
    disp('Press <Enter> to overwrite them, Ctrl-C to cancel');
    pause;
    
    force=true;
  end
  
  xml_save(s.xml_name, s);
  xmlFiles{h}=s.xml_name;
  
  putDot(h);
end
disp(' ');

% collect the xml files and save them
eval(['xml', datasetName, 'FileNames=xmlFiles;']);
eval([datasetName, 'Path=''', datasetDir, ''';']);
save(['/home/marco/research/projects/AB_Clustering/testing/xml', ...
  datasetName, 'FileNames.mat'], 'xmlFiles', ...
  ['xml', datasetName, 'FileNames'], ...
  [datasetName, 'Path']);

% AUTORIGHTS
% Copyright (C) 2008-2012 Marco Andreetto
%       
% This file is part of AB_SAMPLER.
% 
% AB_SAMPLER is free software; you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation; either version 2, or (at your option)
% any later version.
% 
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
% 
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software Foundation,
% Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
