function [C, P]=extractMAP(samples, K)
%EXTRACTMAP extracts MAP clustering from samples
%   [C, P]=EXTRACTMAP(SAMPLES, K) extracts for each observation the MAP 
%   clustering assignment based on the samples 'samples'. 
%   The probability 'P' of being in each cluster is also computed.
%   If the second argument 'K' is not provided it is obtained as the
%   maximum label in 'samples'
%

[N, S]=size(samples); 

if nargin<2
  % get the number of cluster as the maximum value in the samples
  K=round(max(samples(:)));
end

% compute the probabilities
P=zeros(N, K);
for k=1:K
  P(:,k)=sum(samples==k, 2);
end
P=P/S;

% get the MAP value
[M, C]=max(P, [], 2);
nop(M);

% AUTORIGHTS
% Copyright (C) 2008-2012 Marco Andreetto
%       
% This file is part of AB_SAMPLER.
% 
% AB_SAMPLER is free software; you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation; either version 2, or (at your option)
% any later version.
% 
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
% 
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software Foundation,
% Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
