function [Ae, Xe, row_num, col_num, imageEdges]=extract_IC(pos, imageFileName)
%
% Extract the Intervening countout for the points of position 'pos'
%


%
% Check if there is a file with the affinities from IC contour.
%


affFileName=retriveDataFiles(imageFileName, 'ic');

% % base directory for the images
% baseDirImages='/common/bart/core/work/databases/databases003/caltech4freeman130rows/';
% baseDirAff='/common/marco/clustering/datasets/Eugene/';
% 
% % extract the image name without the path
% fileName=imageFileName(length(baseDirImages):end);
% 
% affFileName=strcat(baseDirAff, ...
%                    fileName, ...
%                    '.ic_aff.mat');


if ~exist(affFileName, 'file')
  %
  % compute the affinities and save them in the file
  %
  
  % load the image and convert in double format 0-1.
  I=double(imread(imageFileName))/255;
  
  % compute the IC.
  disp(['Extracting IC', imageFileName]);
  [A, X, imageEdges]=TA_IC_affinities(I);
  
  % get also the dimension of the image
  row_num=rows(I);
  col_num=cols(I);
  
  % save the affinity file
  save(affFileName, 'A', 'X', 'imageEdges', 'row_num', 'col_num');
end

load(affFileName, 'A', 'X', 'row_num', 'col_num');
X=double(X);


%
% Extract the affinities of the given points
% 

% convert the positions 'pos' into pixels coordinates. We assume that the
% coordinates are referred to the top left corner of the image. We also
% assume that the coordinates are spanning the same range of the image.

% the first coordinate is the x which correspond to the column of the
% image. The second coordinate is the y which correspond to the rows.
c_idx=round(pos(:, 1));
r_idx=round(pos(:, 2));

% we need to convert the indeces to the linear case
idx=sub2ind([row_num, col_num], r_idx, c_idx);

Ae=A(idx, idx);
Xe=X(idx, :);


% AUTORIGHTS
% Copyright (C) 2008-2012 Marco Andreetto
%       
% This file is part of AB_SAMPLER.
% 
% AB_SAMPLER is free software; you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation; either version 2, or (at your option)
% any later version.
% 
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
% 
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software Foundation,
% Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
