function visualWordInfo=getAllVisualWordInfo(types, dataset, ncenters, ...
                                              xmlFiles, recompute)
%
% visualWordInfo=getAllVisualWordInfo(types, dataset, number_of_centers,
%                                       xmlFiles, recompute)
%
% Load all the information for all the visual word types into an array of
% structures.
%

% by default we use a cached set of visual words if present.
if nargin<5, recompute=false; end                                                       
                                                       
% iterate over all the visual word types and load the information into an
% array of structures.

% empty array of structure
visualWordInfo=struct('centers', {}, 'mu', {}, 'L', {}, 'info', {}, 'type', {});

for h=1:length(types)
  
  [centers, mu, L, info]=getVisualWordCenters(types{h}, dataset, ncenters, ...
                                              xmlFiles, recompute);
  visualWordInfo=cat(1, visualWordInfo, struct('centers', centers, 'mu', mu, ...
                                               'L', L, 'info', info, ...
                                               'type', types{h}));
end

% AUTORIGHTS
% Copyright (C) 2008-2012 Marco Andreetto
%       
% This file is part of AB_SAMPLER.
% 
% AB_SAMPLER is free software; you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation; either version 2, or (at your option)
% any later version.
% 
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
% 
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software Foundation,
% Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
