function X=getFeatureVectors(I)
%
%X=getFeatureVectors(I)
% 
%  Given an image 'I' computes the feature vectors associated to each pixel.
%  The vectors are returned in the matrix 'X' of dimension NxF, with N the
%  number of pixels and F the dimension of the feature space. If the image is
%  in grayscale then F is 3: one dimension for the intensity and 2 for the
%  pixel position in the image. If the image is in RGB format then F=5: three
%  dimensions for the color information and two dimensions for the pixel
%  positions.
%  The pixels in the image are scanned in column order (following MATLAB
%  convention). The image must be in double format with value in (0-1).
% 
%  Marco Andreetto, Caltech 2009
% 

% =========================================================================
% check the input
% =========================================================================
if ~isa(I, 'double')
  error('getFeatureVectors: I must be double');
end

if max(max(max(I)))>1
  error('getFeatureVectors: values in I must be in the 0-1 range');
end


% =========================================================================
%  Compute the feature vectors X
% =========================================================================

num_row=rows(I);
num_col=cols(I);


% vectors with the observation coordinates. All the coordinates refer to the 
% center of the image.
ix=(1:num_col)-(num_col/2);
iy=(1:num_row)-(num_row/2);
[Px, Py]=meshgrid(ix, iy);

% the input image for this function has range 0-1. The following processing
% assume a 0-255 range to be comparable with the coordinate values of Px and Py.
% We have to rescale the color.
X=[reshape(255*I, rows(I)*cols(I), []), Px(:), Py(:)];

% AUTORIGHTS
% Copyright (C) 2008-2012 Marco Andreetto
%       
% This file is part of AB_SAMPLER.
% 
% AB_SAMPLER is free software; you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation; either version 2, or (at your option)
% any later version.
% 
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
% 
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software Foundation,
% Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
