function G=getResponseFilterBank(I)
%
% Filter an RGB image with a set of filter banks
%

% preallocate the output
G=zeros(rows(I), cols(I), 17);

c=1;

% convert in lab
I = applycform(I,makecform('srgb2lab'));

% gaussian smoothing of the three channels with different value of sigma
g_sigmas=[1, 2, 4];

idx=1:3;
for l=1:length(g_sigmas)
  G(:,:,idx)=vl_imsmooth(I, g_sigmas(l));
  idx=idx+3; % move to the next set filter respons
  
  c=c+3;
end


% compute the derivative with respect the two images at two different
% scales
[G(:,:,c), G(:,:,c+1)]=gradient(G(:, :, 4)); % scale 2 gaussian filter output
c=c+2;

[G(:,:,c), G(:,:,c+1)]=gradient(G(:, :, 7)); % scale 4 gaussian filter output
c=c+2;

% finally compute the 4 laplacian
L=-1*ones(3,3);
L(2,2)=8;

G(:,:,c)=conv2(G(:,:,1), L, 'same'); % LoG at scale 1
c=c+1;

G(:,:,c)=conv2(G(:,:,4), L, 'same'); % LoG at scale 2
c=c+1;

G(:,:,c)=conv2(G(:,:,7), L, 'same'); % LoG at scale 4
c=c+1;

% finally a LoG at scale 8
G(:,:, c)=conv2(vl_imsmooth(I(:,:,1), 8), L, 'same');

% AUTORIGHTS
% Copyright (C) 2008-2012 Marco Andreetto
%       
% This file is part of AB_SAMPLER.
% 
% AB_SAMPLER is free software; you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation; either version 2, or (at your option)
% any later version.
% 
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
% 
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software Foundation,
% Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
