function G=getResponseGaborFilterBank(I)
%
% Filter an RGB image with a set of filter banks
%

% convert the image in grayscale
if size(I, 3)==3
  I=rgb2gray(I);
end


% gaussian smoothing of the image with different value of sigma
g_sigmas=[1, 2];

% create the multiscale structure
I_s=zeros(rows(I), cols(I), length(g_sigmas));
for h=1:length(g_sigmas)
  I_s(:,:,h)=vl_imsmooth(I, g_sigmas(h)); % first scale  2
end

% load the gabor filter bank G1 and G2 (they are in quadrature phase).
load gabor_filters gb1 gb2;

% number of filters
NF=size(gb1, 3);

Dim=2*(1*NF+1); % four the dimension of one filter bank and two laplacian

G=zeros(rows(I), cols(I), Dim);

c=1;

% expression for the laplacian
L=-1*ones(3,3);
L(2,2)=8;

% iterate over all the scales
for s=1:size(I_s, 3)
  % compute the laplacian
  G(:,:,c)=conv2(I_s(:,:,s), L, 'same');
  %display_filter_output(G(:,:,c), ['L ', num2str(s)]);
  c=c+1;
  
%   % iterate over all the first filter bank
%   for h=1:NF
%     G(:,:,c)=conv2(I_s(:,:,s), gb1(:,:,h), 'same'); 
%     display_filter_output(G(:,:,c), ['GB1 ', num2str(s), ' ', num2str(h)]);
%     c=c+1;
%   end

  % iterate over all the second filter bank
  for h=1:NF
    G(:,:,c)=conv2(I_s(:,:,s), gb2(:,:,h), 'same'); 
    %display_filter_output(G(:,:,c), ['GB2 ', num2str(s), ' ', num2str(h)]);
    c=c+1;
  end
  
end

function display_filter_output(F, figTitle, figNumber) %#ok<DEFNU>

% if no 'figNumber' open a new one
if nargin<3
  figure;
else
  figure(figNumber);
end

F=abs(fftshift(fft2(F)));

imagesc(F(5:(end-5), 5:(end-5)));
colormap gray;
axis equal off;
title(figTitle);

% AUTORIGHTS
% Copyright (C) 2008-2012 Marco Andreetto
%       
% This file is part of AB_SAMPLER.
% 
% AB_SAMPLER is free software; you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation; either version 2, or (at your option)
% any later version.
% 
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
% 
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software Foundation,
% Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
