function [centers, mu, L, info]=getVisualWordCenters(varargin)
%
% [centers, mu, L, info]=getVisualWordCenters(file_name)
%
% [centers, mu, L, info]=getVisualWordCenters(type, dataset, number_of_centers)
%
% Two versions. The first one is the oldest one and has only one input argument
% the name of the file with the visual words. The second version use the
% inputs to obtain the name of the file with the visual words. If this file
% is non present the it is computed and cached.
%

if (nargin==1)
  % this is the old version that use the string to get the file with the
  % visual words.
  [centers, mu, L, info]=getVisualWordCentersVer1(varargin{:});
else
  % this is the new version. It compose the name of the file with the
  % visual word and load it. If no file is present the visual words are
  % computed and cached.
  [centers, mu, L, info]=getVisualWordCentersVer2(varargin{:});
end


function [centers, mu, L, info]=getVisualWordCentersVer1(type) %#ok<STOUT>

basePath='/home/marco/research/projects/AB_Clustering/visual_word_centers/';

info.type=type;
info.centerFile=[basePath, type];
load(info.centerFile, 'centers', 'mu', 'L');
info.dictionary_size=rows(centers);
info.space_dim=cols(centers);

% % only the SIFT visual words are a GMM instead of a set of kmeans center
% if isa(centers, 'double')
%   info.dictionary_size=rows(centers);
%   info.space_dim=cols(centers);
% else
% %   info.space_dim=rows(centers.centers);
% %   info.dictionary_size=centers.K^centers.depth;
%   info.dictionary_size=vocab.ncentres;
%   info.space_dim=vocab.nin;
% end


function [centers, mu, L, info]=getVisualWordCentersVer2(type, dataset, ncenters, ....
                                                         xmlFiles, recompute)
% by default we use a cached set of visual words if present.
if nargin<5, recompute=false; end                                                       
                                                       
% where the visual words are
basePath='/home/marco/research/projects/AB_Clustering/visual_word_centers/';

% compose the name of the visual word file
visual_word_file_name=[type, '_centers_', num2str(ncenters), '_', dataset];

% get all the version of this file (without the extension)
wordFiles=getAllFilesInDir(basePath, [visual_word_file_name, '_2*.mat'], ...
                           'extension', false, 'path', false);

% check if there is a file if a file is not present we create it.
if isempty(wordFiles) || recompute
  
  disp(' ');
  disp(['Dataset:', dataset, '. Visual words type: ', type]);
  if (recompute)
    disp('Forcing the creation of a new set of visual word');
  else
    disp('Missing visual word file. Creating a new set of visual words');
  end
  
  % we have to compute the centers for this dataset save it and load it. By
  % default we always normalize the texture.
  [centers, mu, L]=compVisualWordCenters(type, xmlFiles, ncenters); %#ok<ASGLU>
  
  % save the visual words into a mat file. We put a tag with the curret
  % date.
  wordFiles={strcat(visual_word_file_name, '_', datestr(date, 'yyyymmdd'))};
  save([basePath, wordFiles{1}], 'centers', 'mu', 'L');
  disp('Saving visual word in file');
  disp(wordFiles{1});
  
end

% call the old version with the file name
[centers, mu, L, info]=getVisualWordCentersVer1(wordFiles{end});



% info.type=type;
% 
% % load the kmeans centers (this version has the patches normalized)
% switch lower(type)
% 
%   case 'horse'
%     info.centerFile=[basePath, 'texture_centers_256c.mat'];
%     load(info.centerFile, 'texture_words', 'mu', 'L');
%     centers=texture_words;
% 
% 
%   case 'labelme'
%     info.centerFile=[basePath, 'texture_centers_256_labelme.mat'];
%     load(info.centerFile, 'texture_words', 'mu', 'L');
%     centers=texture_words;
% 
%     
%   case 'color_centers_256_msrc_20080731'
%     % color visual words
%     info.centerFile=[basePath, 'color_centers_256_msrc_20080731.mat'];
%     load(info.centerFile, 'color_words');
%     centers=color_words;
%     
%     % for the color visual word we do not need to normalize, therefore the
%     % L and mu variables are empty.
%     L=[];
%     mu=[];
% 
%   case 'color_centers_512_msrc_20080731'
%     % color visual words
%     info.centerFile=[basePath, 'color_centers_512_msrc_20080731.mat'];
%     load(info.centerFile, 'color_words');
%     centers=color_words;
%     
%     % for the color visual word we do not need to normalize, therefore the
%     % L and mu variables are empty.
%     L=[];
%     mu=[];
% 
%   case 'color_centers_1024_msrc_20080731'
%     % color visual words
%     info.centerFile=[basePath, 'color_centers_1024_msrc_20080731.mat'];
%     load(info.centerFile, 'color_words');
%     centers=color_words;
%     
%     % for the color visual word we do not need to normalize, therefore the
%     % L and mu variables are empty.
%     L=[];
%     mu=[];
% 
% 
%   case 'texture_centers_256_msrc_20080731_normalized'
%     % texture visual words
%     info.centerFile=[basePath, 'texture_centers_256_msrc_20080731_normalized.mat'];
%     load(info.centerFile, 'texture_words', 'mu', 'L');
%     centers=texture_words;
%     
%     
%   case 'texture_centers_512_msrc_20080731_normalized'
%     % texture visual words
%     info.centerFile=[basePath, 'texture_centers_512_msrc_20080731_normalized.mat'];
%     load(info.centerFile, 'texture_words', 'mu', 'L');
%     centers=texture_words;
%     
%     
%   case 'texture_centers_1024_msrc_20080731_normalized'
%     % texture visual words
%     info.centerFile=[basePath, 'texture_centers_1024_msrc_20080731_normalized.mat'];
%     load(info.centerFile, 'texture_words', 'mu', 'L');
%     centers=texture_words;
%         
% 
%   case 'sift_centers_256_msrc_20080806'
%     % sift visual words
%     info.centerFile=[basePath, 'sift_centers_256_msrc_20080806.mat'];
%     load(info.centerFile, 'sift_words');
%     centers=sift_words;
%         
%     % for the color visual word we do not need to normalize, therefore the
%     % L and mu variables are empty.
%     L=[];
%     mu=[];
% 
%     
%   case 'sift_centers_512_msrc_20080806'
%     % sift visual words
%     info.centerFile=[basePath, 'sift_centers_512_msrc_20080806.mat'];
%     load(info.centerFile, 'sift_words');
%     centers=sift_words;
%         
%     % for the color visual word we do not need to normalize, therefore the
%     % L and mu variables are empty.
%     L=[];
%     mu=[];
% 
%     
%   case 'sift_centers_1024_msrc_20080806'
%     % sift visual words
%     info.centerFile=[basePath, 'sift_centers_1024_msrc_20080806.mat'];
%     load(info.centerFile, 'sift_words');
%     centers=sift_words;
%         
%     % for the color visual word we do not need to normalize, therefore the
%     % L and mu variables are empty.
%     L=[];
%     mu=[];
% 
%     
%   case 'sift_centers_256_msrc_20080813'
%     % sift visual words
%     info.centerFile=[basePath, 'sift_centers_256_msrc_20080813.mat'];
%     load(info.centerFile, 'sift_words');
%     centers=sift_words;
%         
%     % for the color visual word we do not need to normalize, therefore the
%     % L and mu variables are empty.
%     L=[];
%     mu=[];
% 
%     
%   case 'sift_centers_512_msrc_20080813'
%     % sift visual words
%     info.centerFile=[basePath, 'sift_centers_512_msrc_20080813.mat'];
%     load(info.centerFile, 'sift_words');
%     centers=sift_words;
%         
%     % for the color visual word we do not need to normalize, therefore the
%     % L and mu variables are empty.
%     L=[];
%     mu=[];
% 
%     
%   case 'sift_centers_1024_msrc_20080813'
%     % sift visual words
%     info.centerFile=[basePath, 'sift_centers_1024_msrc_20080813.mat'];
%     load(info.centerFile, 'sift_words');
%     centers=sift_words;
%         
%     % for the color visual word we do not need to normalize, therefore the
%     % L and mu variables are empty.
%     L=[];
%     mu=[];
% 
%     
%   case 'sift_centers_1024_msrc_20090330'
%     % sift visual words
%     info.centerFile=[basePath, 'sift_centers_1024_msrc_20090330.mat'];
%     load(info.centerFile, 'sift_words');
%     centers=sift_words;
%         
%     % for the color visual word we do not need to normalize, therefore the
%     % L and mu variables are empty.
%     L=[];
%     mu=[];
% 
%     
%   case 'sift_tree_20090331'
%     info.centerFile=[basePath, 'sift_tree_20090331.mat'];
%     load(info.centerFile, 'tree');
%     centers=tree;
%         
%     L=[];
%     mu=[];
% 
%     
%   case 'sift_centers_256_20090921'
%     info.centerFile=[basePath, 'sift_centers_256_20090921.mat'];
%     load(info.centerFile, 'vocab');
%     centers=vocab;
%     
%     L=[];
%     mu=[];
%     
%     
%   case 'sift_centers_iccv_faces_256_20090921'
%     info.centerFile=[basePath, 'sift_centers_iccv_faces_256_20090921.mat'];
%     load(info.centerFile, 'vocab');
%     centers=vocab;
%     
%     L=[];
%     mu=[];
%     
%     
%   case 'texture_centers_1024_coast_scene_20090406'
%     % texture visual words
%     info.centerFile=[basePath, 'texture_centers_1024_coast_scene_20090406.mat'];
%     load(info.centerFile, 'texture_words', 'mu', 'L');
%     centers=texture_words;
%     
%   case 'texture_centers_1024_forest_scene_20090406'
%     % texture visual words
%     info.centerFile=[basePath, 'texture_centers_1024_forest_scene_20090406.mat'];
%     load(info.centerFile, 'texture_words', 'mu', 'L');
%     centers=texture_words;
%     
%   case 'texture_centers_1024_highway_scene_20090406';
%     % texture visual words
%     info.centerFile=[basePath, 'texture_centers_1024_highway_scene_20090406.mat'];
%     load(info.centerFile, 'texture_words', 'mu', 'L');
%     centers=texture_words;
%     
%   case 'texture_centers_1024_inside_city_scene_20090406'
%     % texture visual words
%     info.centerFile=[basePath, 'texture_centers_1024_inside_city_scene_20090406.mat'];
%     load(info.centerFile, 'texture_words', 'mu', 'L');
%     centers=texture_words;
%    
%   case 'texture_centers_1024_mountain_scene_20090406'
%     % texture visual words
%     info.centerFile=[basePath, 'texture_centers_1024_mountain_scene_20090406.mat'];
%     load(info.centerFile, 'texture_words', 'mu', 'L');
%     centers=texture_words;
%     
%   case 'texture_centers_1024_open_country_scene_20090406'
%     % texture visual words
%     info.centerFile=[basePath, 'texture_centers_1024_open_country_scene_20090406.mat'];
%     load(info.centerFile, 'texture_words', 'mu', 'L');
%     centers=texture_words;
%     
%   case 'texture_centers_1024_scene_20090406'
%     % texture visual words
%     info.centerFile=[basePath, 'texture_centers_1024_scene_20090406.mat'];
%     load(info.centerFile, 'texture_words', 'mu', 'L');
%     centers=texture_words;
%     
%   case 'texture_centers_1024_street_20090406'
%     % texture visual words
%     info.centerFile=[basePath, 'texture_centers_1024_street_20090406.mat'];
%     load(info.centerFile, 'texture_words', 'mu', 'L');
%     centers=texture_words;
%         
%   case 'texture_centers_1024_tall_building_20090406'
%     % texture visual words
%     info.centerFile=[basePath, 'texture_centers_1024_tall_building_20090406.mat'];
%     load(info.centerFile, 'texture_words', 'mu', 'L');
%     centers=texture_words;
%         
%   case 'texture_centers_1024_iccv_faces_20090928'
%     % texture visual words
%     info.centerFile=[basePath, 'texture_centers_1024_iccv_faces_20090928.mat'];
%     load(info.centerFile, 'texture_words', 'mu', 'L');
%     centers=texture_words;
%         
%   case 'texture_centers_1024_iccv_faces_20090921_normalized'
%     % texture visual words
%     info.centerFile=[basePath, 'texture_centers_1024_iccv_faces_20090928.mat'];
%     load(info.centerFile, 'texture_words', 'mu', 'L');
%     centers=texture_words;
%         
%   case 'gabor_centers_256_msrc_20090407_normalized'
%     % texture visual words
%     info.centerFile=[basePath, 'gabor_centers_256_msrc_20090407_normalized.mat'];
%     load(info.centerFile, 'texture_words', 'mu', 'L');
%     centers=texture_words;
%         
%   case 'hue_centers_1024_msrc_20090925'
%     info.centerFile=[basePath, 'hue_centers_1024_msrc_20090925.mat'];
%     load(info.centerFile, 'hue_words');
%     centers=hue_words;
%     L=[]; mu=[];
%     
%   case 'color_centers_1024_iccv_faces_20090928'
%     info.centerFile=[basePath, 'color_centers_1024_iccv_faces_20090928.mat'];
%     load(info.centerFile, 'color_words');
%     centers=color_words;
%     L=[]; mu=[];
%     
%   case 'hue_centers_1024_iccv_faces_20090928'
%     info.centerFile=[basePath, 'hue_centers_1024_iccv_faces_20090928.mat'];
%     load(info.centerFile, 'hue_words');
%     centers=hue_words;
%     L=[]; mu=[];
%     
%   otherwise
%     error('Unrecognize dataset');
% 
% end
% 

% AUTORIGHTS
% Copyright (C) 2008-2012 Marco Andreetto
%       
% This file is part of AB_SAMPLER.
% 
% AB_SAMPLER is free software; you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation; either version 2, or (at your option)
% any later version.
% 
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
% 
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software Foundation,
% Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
