function I=labels2ind(C, K, type)
%
% Transform a set of labels C corresponding to a culster assignement
% into the equivalent indicator matrix I.
% if C is a vector of dimension N then I is a matrix of NxK with K number
% of unique labels in C. K can also be specified as input.
%

N=length(C); % number of observations

if nargin<2, K=max(C); end % number of cluster
if nargin<3, type='full'; end % number of cluster

I=zeros(N, K);
for k=1:K, I(:,k)=(C==k); end

% % we also have to clean up possible empty columns
% I(:, (sum(I)==0))=[];

% return a sparse 
switch lower(type)
  case 'sparse'
    I=sparse(I);
    
  case 'logical'
    I=logical(I);
    
  case 'full'
    
  otherwise 
    error('Unrecognized returning type');
end
    
% AUTORIGHTS
% Copyright (C) 2008-2012 Marco Andreetto
%       
% This file is part of AB_SAMPLER.
% 
% AB_SAMPLER is free software; you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation; either version 2, or (at your option)
% any later version.
% 
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
% 
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software Foundation,
% Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
