function [W, ix, iy, scales, R]=loadPatchInfo_filters(ifn, step, recompute, type)

if nargin<2, step=2; end;
if nargin<3, recompute=false; end;
if nargin<4, type='msrc'; end;

% load the image
I=im2double(imread(ifn));
M=rows(I);
N=cols(I);

% the position of the grid nodes on the x axis (columns), and y axis (rows)
start=4; % previously we used 10
ix_range=start:step:N;
iy_range=start:step:M;

% construct the position of the color words
[ix, iy]=meshgrid(ix_range, iy_range);

ix=ix(:);
iy=iy(:);

scales=ones(size(ix));

% get the filter version of the image
fofn=[ifn, '.filter.mat'];

W=[];
if (~exist(fofn, 'file') || recompute)
  
  tic;
  % create the filter output of the given image
  G=getResponseFilterBank(I);

  % extract all the fileters we need
  R=reshape(G(iy_range, ix_range, :), [length(ix), size(G, 3)]);
  
  % load the kmeans centers (this version has the patches normalized)  
  switch lower(type)
    case 'msrc'
      load('/home/marco/research/projects/AB_Clustering/prepare_data/texture_centers_256_msrc.mat',...
           'texture_words', 'mu', 'L');
         
    case 'horse'
      load('/home/marco/research/projects/AB_Clustering/prepare_data/texture_centers_256c.mat', ...
           'texture_words', 'mu', 'L');
         
    case 'labelme'
      load('/home/marco/research/projects/AB_Clustering/prepare_data/texture_centers_256_labelme.mat', ...
           'texture_words', 'mu', 'L');
         
    case 'scenes'
      load('/home/marco/research/projects/AB_Clustering/prepare_data/texture_centers_256_scenes.mat', ...
           'texture_words', 'mu', 'L');
         
    otherwise
      error('Unrecognize dataset');
         
  end
  
  % normalize the points in space
  R=R-repmat(mu, rows(R), 1);
  R=(inv(L')*R')';

  [d, W]=mindist(texture_words', R');
  W=W(:);
  
  save(fofn, 'G', 'W');
  toc;
end

% load the centers and compute the visual words
load(fofn, 'W');

% AUTORIGHTS
% Copyright (C) 2008-2012 Marco Andreetto
%       
% This file is part of AB_SAMPLER.
% 
% AB_SAMPLER is free software; you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation; either version 2, or (at your option)
% any later version.
% 
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
% 
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software Foundation,
% Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
