'''
Make the webpage for the segmentation results.
The page is constructed by collecting all the images in the specified 
directories. All the directories should have the same number of files.
In practice the directory with the smallest number of files sets the 
number for all the other.
'''

# The module used for the construction of the webpages
import markup, sys, os, os.path
from glob import *


#
# Global variables fixed during the whole set of experiments. These are all 
# the variable that have to be modified to create a new webpage for the results
#


# base URL for the results:
baseURL = "http://www.vision.caltech.edu/marco/projects/clustering/Journal/"

# base path in the filesystem
basePath = "/common/marco/clustering/results/Journal/"

# title
webPageTitle= '''Random Assignment.'''

# template name for the file we want to extract from the directories
templateFile=["msrc_*.png", 
              "seg_class_0*[0-9].png",
              "seg_class_0*[0-9].png",
             ]

descStr = ["Original, ",
           "No pruning, ", 
           "Pruning, ",
          ]

# all the sub directories 
sub_dirs = ["msrc/", 
            "20100607b_0027/",
            "20100607c_0027/",
           ]

expDesc = "Comparison of the the random assignment at pixel and superpixel level."
expTag=""

#------------------------------------------------------------------------------
#
# This part of the code should always be the same no matter what we want to 
# show in the webpage.
#


class createPage:
  '''
  This class contains all the data and the methods to create the results page
  '''

  def __init__(self):
    '''
    Define all the constant and variables used to construct the script.
    The constants describe the fixed setting of each experiment page.
    The variables are used to customize the result page.
    '''

  def getFiles(self, directory, expression="*.png"):
    '''
    Returns the list of images in directory 'directory' that have match 
    regular expression 'exp'. By default the regular expression is '*.png'.
    '''
    
    # compose the complete regular expression
    expression=os.path.join(basePath, directory)+'/'+expression
    
    # get all the files that match the expresion
    image_list=glob(expression)
    
    # finally sort the list by name
    image_list.sort()
    
    # remove the base directory from all the entries of the list
    image_list=[x[len(basePath):] for x in image_list]
    
    print directory
    print len(image_list)
    
    return image_list
 

  def do(self):
    '''
    Construct the webpage with all the results and return the object that 
    contains it.
    '''

    # create the HTML page object 
    mainPage = markup.page()

    # start to fill in the page
    mainPage.init(title = webPageTitle, header = webPageTitle + "  ", 
                  footer = "", css = ('layout.css', 'alt.css', 'images.css'))

    # insert a link to the research log
    #mainPage.a("Marco's research Log", \
    #            href="http://www.vision.caltech.edu/VisionWiki/"
    #                 "index.php?title=Marco_research_Log")
    mainPage.br()
    
    # insert the experiment description
    mainPage.p(expDesc)

    # a couple of page break
    mainPage.br()
    mainPage.br()

    # get the lists of images that will compose the page
    numImages=100000;  
    
    lists_of_images = []
    
    for h in range(len(sub_dirs)):
      lists_of_images.append( self.getFiles(sub_dirs[h], templateFile[h]) )
      numImages=min(numImages, len(lists_of_images[-1]))
      
    # iterate over all the lists of directories and compose the page
    for h in range(numImages):
      
      # first part of the caption string
      imageNumberString="Image "+str(h+1)+" "
      
      captionString = " "
      
      # iterate over all the sub directories and insert the images
      for k in range(len(lists_of_images)):
        mainPage.img(src=lists_of_images[k][h], alt=descStr[k])
        captionString += (descStr[k] + "      ")
      
      #
      # insert a link for the details of the experiment
      #
      
      # construct the auxiliary info file name
      auxFileName='seg_aux_info_%04d.txt' % (h+1)
      
      #
      # construct the html output file
      #
      # htmlSubPage='detail_%04d.html' % (h+1)
      # createDetailPage.do(lists_of_images[0][h], \
      #                    h, \
      #                    basePath+expTag+auxFileName, \
      #                    basePath+expTag+htmlSubPage);
      
      # # insert the link to the subpage in the
      # mainPage.a("Details for global term", \
      #            href=baseURL+expTag+'/'+htmlSubPage)
      
      mainPage.p(imageNumberString)
      mainPage.p(captionString)
      mainPage.br() # insert a page-break

    # end for

    # put some page breaks
    mainPage.br()
    mainPage.br()

    mainPage.a("Marco's research Log", \
                href="http://www.vision.caltech.edu/VisionWiki/"
                     "index.php?title=Marco_research_Log")

    return mainPage

  # end def do
  
# end class createPage



#
# main block of the script
#

# check the arguments
usageMsg="Usage: "+sys.argv[0]+" <htmlFile>"
if len(sys.argv)!=2:
  print usageMsg
  sys.exit(1)


# create the main object and construct the page
cp=createPage()
htmlPage=cp.do()

# create the file into the html directory
htmlFileName=sys.argv[1]
if ".html" not in htmlFileName:
  htmlFileName+=".html"
  
htmlFile = file(basePath + htmlFileName, "w") # open the ouput file
print >> htmlFile, htmlPage # save the results and close the file
htmlFile.close()
