function makeSegBoundaries(xmlFile, pattern, baseOutName, displayOnScreen)

%
% 
%

if nargin<4, displayOnScreen=false; end

disp('Construct and save the images with the segment boundaries');

% info about the experiment
expInfo=readXMLfile(xmlFile);

% collect all the specified files from result directory
segFiles=getAllFilesInDir(expInfo.destDir, pattern);

% check the number of images from the variable 'pattern' vs. the
% number of images used in the experiments.
if (length(segFiles) ~= length(expInfo.data_file_info))
  error('Wrong number of segmentations!' );
end

for h=1:length(segFiles)
  
  % load the segmentation 
  load(segFiles{h}, 'segImageMAP');
  
  % create the image with the segmentation boundaries
  I=imread(expInfo.data_file_info{h}.original_name);
  segBoundaries=segImage(I, segImageMAP);
  
  outFileName=sprintf('%s/%s_%04d.png', expInfo.destDir, baseOutName, h);
  imwrite(segBoundaries, outFileName);

  if displayOnScreen,
    % display the segmentation images (for debugging porpuse)
    figure(1);
    imshow(outFileName);
    title(num2str(h));
    pause(0.25);
  end

  putDot(h);
end
disp(' ');

disp(' ');

% AUTORIGHTS
% Copyright (C) 2008-2012 Marco Andreetto
%       
% This file is part of AB_SAMPLER.
% 
% AB_SAMPLER is free software; you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation; either version 2, or (at your option)
% any later version.
% 
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
% 
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software Foundation,
% Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
