function make_performance_plot(varargin)

%
% Display the missed detection and the false allarm for a set of errors.
% 

% By default we do not draw any arrow in the plot
useArrow=false;

% By default we do put the legend
useLegend=false;

% And we do not put any label on the plot
class_labels={};

% the output file
fileName='';


s=1; % we assume no option

while isa(varargin{s}, 'char')
  
  % the current argument is an option
  
  switch lower(varargin{s})
    
    case 'arrow',   useArrow=varargin{s+1};      
    case 'labels',  class_labels=varargin{s+1};
    case 'outfile', fileName=varargin{s+1};
    case 'legend',  useLegend=varargin{s+1};
      
    otherwise, error('Unrecognized option');
  end
  
  s=s+2; % move to the next set of input and repeat the cycle.
end


%
% we have set all the options. Extract all the errors with their marker 
% and identifiers. 
%

% check that the number of input is a multiple of 3.
if mod((nargin-s+1), 3) ~= 0
  error('Wrong number of inputs');
end

errors={}; % errors to plot
style={}; % plot style
desc={}; % description for the errors

for l=s:3:nargin
  errors=cat(2, errors, varargin{l});
  style=cat(2, style, varargin{l+1});
  desc=cat(2, desc, varargin{l+2});  
end


% 
% Construct the plot 
%

ph=cell(1, length(errors));
ph{1}=mfa_plot(errors{1}, style{1}, class_labels);
hold on;

for l=2:length(errors)
  ph{l}=mfa_plot(errors{l}, style{l}, class_labels);
end
hold off;
grid on;

xlabel('Miss Detection (log)', 'FontSize', 14);
ylabel('False alarm (log)', 'FontSize', 14);

if useLegend, legend(desc, 'Location', 'NorthWest'); end

% set the limits of the plot
axis([0.01 1 0.01 1]);

if useArrow, insert_arrows(ph{1}, ph{2}); end

drawnow;

%
% Finally we save the plot if required
%

if ~isempty(fileName), saveas(gcf, fileName); end



function ph=mfa_plot(errors, marker, class_labels)

% display the missed/false_alarm points for every specific class
missed=1-errors(:, 1);
false_alarm=errors(:, 2);

% ph=loglog(missed, false_alarm, marker, 'MarkerSize', 15, 'LineWidth', 2);
ph=plot(missed, false_alarm, marker, 'MarkerSize', 15, 'LineWidth', 2);

if ~isempty(class_labels)
  text(missed, false_alarm+0.003, class_labels, 'FontSize', 14);
end



function insert_arrows(ph1, ph2)

xpos1=get(ph1, 'XData');
ypos1=get(ph1, 'YData');

xpos2=get(ph2, 'XData');
ypos2=get(ph2, 'YData');

for h=1:length(xpos1)
  line([xpos1(h) xpos2(h)], [ypos1(h) ypos2(h)], ...
       'lineWidth', 2, 'Color', 'k');
%   arrowh([xpos1(h) xpos2(h)], [ypos1(h) ypos2(h)], 'k');
end

% AUTORIGHTS
% Copyright (C) 2008-2012 Marco Andreetto
%       
% This file is part of AB_SAMPLER.
% 
% AB_SAMPLER is free software; you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation; either version 2, or (at your option)
% any later version.
% 
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
% 
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software Foundation,
% Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
