function tableStr=make_performance_table(varargin)

%
% Display the missed detection and the false allarm for a set of errors.
% 

% default parameters
useWangGrimson=true;
usePOCV=true;
tableType='wiki';
ready=false;

s=1;
while ~ready
  
  % the current argument is an option
  
  switch lower(varargin{s})
    
    case 'useWangGrimson'
      useWangGrimson=varargin{s+1};
           
    case 'usePOCV'
      usePOCV=varargin{s+1};
      
    case 'type'
      tableType=varargin{s+1};
           
    case 'tags'
      s=s-1;
      ready=true;
           
    otherwise
      error('Unrecognized option');
      
  end
  
  s=s+2; % move to the next set of input and repeat the cycle.
end


%
% we have set all the options. Extract all the errors with their marker 
% and identifiers. 
%

table={}; % errors

if useWangGrimson
  load errors_wang_grimson.mat errors_wang_grimson;
  table=[table num2cell(errors_wang_grimson)];
end
  
if usePOCV
  load errors_pocv.mat errors_pocv
  table=[table num2cell(errors_pocv)];
end
  
for l=s:nargin
  
  % load the errors from the results file
  [ec, class_labels]=getErrorsFromExpTag(varargin{l});
  table=cat(2, table, num2cell(ec));
end

table=[class_labels table];


switch lower(tableType)
  
  case 'wiki'
    tableStr=printWikiTable(table);
    
  otherwise
    error('Unrecognized format for the table');
    
end 



function [errors, class_labels]=getErrorsFromExpTag(tag)

% construct the results file
fileName=['/common/marco/clustering/results/Journal/', ...
          tag, '/seg_results.mat'];

load(fileName, 'errors');

class_labels=errors(3:end, 1); %#ok<NODEF>
errors=cell2mat(errors(3:end, 2:3));


function table_string=printWikiTable(table)

table_string=[];

for l=1:rows(table)

  table_string=cat(2, table_string, sprintf('|-\n'));  
  for h=1:cols(table)
    
    v=table{l, h};
    
    if isnan(v), v='N/A'; end
    if isa(v, 'double'), v=sprintf('%0.3f', v); end
    
    if h==cols(table)
      table_string=cat(2, table_string, sprintf('| %s ', v));
    else
      table_string=cat(2, table_string, sprintf('| %s |', v));
    end
    
  end
  table_string=cat(2, table_string, sprintf('\n'));  
    
end

% AUTORIGHTS
% Copyright (C) 2008-2012 Marco Andreetto
%       
% This file is part of AB_SAMPLER.
% 
% AB_SAMPLER is free software; you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation; either version 2, or (at your option)
% any later version.
% 
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
% 
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software Foundation,
% Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
