function make_topic_segmentation(xmlFiles)
%
% Given the true topic distribution compute the corresponding segmentation
%

NF=length(xmlFiles); 
load /common/marco/clustering/datasets/sim_noise_images/topic_dist.mat betas thetas_s;

% =========================================================================
%  Setting for the experiment
% =========================================================================
expInfo.K=5;                           % number of clusters/topics
expInfo.alpha=2.0*ones(1, expInfo.K);  % prior used by the sampler
expInfo.lambda=0.0*ones(1, expInfo.K); % weight of the global term (if present)
expInfo.dictionary_size=1024;          % number of visual words in the dict.
expInfo.eta=10;                        % hyperparam for the topic prior dist.
expInfo.grid_step=4;                   % step of the regular grid in the image
expInfo.model_type='AB';               % what type of model is used
expInfo.NI=0;
expInfo.visual_word_info.type='synthetic';

baseDir='/common/marco/clustering/results/Journal/';
destDir=strcat(baseDir, 'topic_seg_map/');

if ~exist(destDir, 'dir')
  mkdir(destDir);
else
  disp(['The directory ', destDir, ' already exist!!!']);
  disp('Press a key to continue');
  pause;
end

% save the destination directory for the results
expInfo.destDir=destDir;

% compute the values
data_files_info={};
Cs_all=cell(NF, 1);

for h=1:NF
  % load the patch info for this image
  W=xmlLoadSimWords(xmlFiles{h});

  % get the maximum likelihood among the topics
  theta=thetas_s{h};
  post=betas(:, W).*repmat(theta(:), 1, length(W));
  [t, Cs]=max(post);
  Cs_all{h}=[Cs' Cs'];
  
  % get the structure info from the xmlFile
  data_files_info=cat(1, data_files_info, xml_load(xmlFiles{h}));
  
  % display the image
  imagesc(reshape(Cs, 59, 79)); 
  axis off; axis equal; colormap gray;
  pause(0.1);
  
  putDot(h);
end
disp(' ');

expInfo.run_time=0;

% save all the results into a single big file
save([destDir, 'seg_results.mat'], 'Cs_all');
% load([destDir, 'seg_results.mat'], 'Cs_all');


%
% complete the 'expInfo' structure and save it.
%

% list of all the data files used in the experiment
expInfo.data_file_info=data_files_info;

% save the xml_file both in the result directory for this experiment and in
% the baseDir
xml_save([destDir, 'experiment_info.xml'], expInfo);
xml_save([baseDir, 'experiment_info_topic_seg_map.xml'], expInfo);


%%

function [W, ix, iy]=xmlLoadSimWords(xmlFile) %#ok<STOUT>

xmlInfo=xml_load(xmlFile);
load([xmlInfo.original_name, '.words.mat'], 'W', 'ix', 'iy');
% AUTORIGHTS
% Copyright (C) 2008-2012 Marco Andreetto
%       
% This file is part of AB_SAMPLER.
% 
% AB_SAMPLER is free software; you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation; either version 2, or (at your option)
% any later version.
% 
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
% 
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software Foundation,
% Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
