function [Cs, Cmap, P]=myPropagateLabels(Cs_sel, imageFileName)
% 
% myPropagation: propagates the labeling of the given grid points using the
% ab_gibbs_sampling.
% 
% Cs_sel: sample assignments for the selected points
%
% imageFileName


%
% compute the MAP assignment for the labeling points
%
Cmap=extractMAP(Cs_sel); % MAP assignement fo the selected points
  

%
% construct the indeces of the points in the original set of observations
%
[W, ix, iy, scales]=loadPatchInfo(imageFileName);
idx_scales=scales<10000; % keep only the small scale features
c_idx=round(ix(idx_scales));
r_idx=round(iy(idx_scales));


%
% construct the fixed labels
%
I=imread(imageFileName);
image_row_num=rows(I);
image_col_num=cols(I);

idx=sub2ind([image_row_num, image_col_num], r_idx, c_idx);
si=zeros(image_row_num*image_col_num, 1);
si(idx)=Cmap;
  

%
% we need also the affinities and the observations for the whole image
% extract the image name without the path
%
[affFileName, patchFileName]=retriveDataFiles(imageFileName, 'lihi');

% baseDirImages='/common/bart/core/work/databases/databases003/caltech4freeman130rows/';
% baseDirAff='/common/marco/clustering/datasets/Eugene/';
% fileName=imageFileName(length(baseDirImages):end);
% 
% % filename for the affinities if we are using lihi method
% affFileName=strcat(baseDirAff, fileName, '.R_11.mat');
%
% % filename for the affinities if we are using Intervening countour
% affFileName=strcat(baseDirAff, fileName, '.ic_aff.mat');
  
load(affFileName, 'A', 'X');
  

%
% Now we can run the sampler for a certain number of iterations
%

% Parameter of the sampler
NI=20*ones(1, 10); NI(1)=50;

% Number of segments in the image
K=max(si); 
alpha=2*ones(1, K);
lambda=0.1*ones(1, K);
tic; Cs=ab_gibbs_sampling(A, X, alpha, NI, [], si, lambda); toc;

[Cmap, P]=extractMAP(Cs);
  

% AUTORIGHTS
% Copyright (C) 2008-2012 Marco Andreetto
%       
% This file is part of AB_SAMPLER.
% 
% AB_SAMPLER is free software; you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation; either version 2, or (at your option)
% any later version.
% 
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
% 
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software Foundation,
% Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
