/* AUTORIGHTS
Copyright (C) 2008-2012 Marco Andreetto
      
This file is part of AB_SAMPLER.

AB_SAMPLER is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2, or (at your option)
any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software Foundation,
Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
*/

#include <iostream>
#include <fstream>
#include <sstream>
#include <cstdlib>
#include <iterator>
#include <algorithm>

#include <boost/numeric/ublas/io.hpp>

#include "my_parallel_library.h"

using namespace std;
using boost::asio::ip::tcp; // we use a tcp socket


// 
// A message is composed as follow:
//
// - unsigned Nd. Number of bytes is sizeof(unsigned)
//
// - ColunmVector SX. Number of bytes is sizeof(Real)*SX.nrows()
// 
// - Matrix SX2. Number of bytes is sizeof(Real)*SX2.ncols()*SX2.nrows()
//


void ExtractStats(const messageType &msg, ublas_vector &SX, ublas_matrix &SX2, 
                  unsigned &Nd)
{
  //
  // Get the offsets for the fields in the message
  //
  
  const unsigned OFFSET_Nd=0;
  const unsigned SIZE_Nd=sizeof(unsigned);
  
  const unsigned OFFSET_SX=OFFSET_Nd+SIZE_Nd;
  const unsigned SIZE_SX=sizeof(double)*SX.size();
  
  const unsigned OFFSET_SX2=OFFSET_SX+SIZE_SX;
  const unsigned SIZE_SX2=sizeof(double)*SX2.size1()*SX2.size2();
  
  // just a temporary buffer where to copy the data extracted from 
  // the ublas types.
  double tmpBuffer[SIZE_SX2];
  
  //
  // parse the message and extract the data
  //
  
  // get the number of observations (msg -> Nd)
  memcpy(&Nd, (msg.body.data())+OFFSET_Nd, SIZE_Nd);
  
  // get SX 
  //
  // First extract the data (msg -> tmpBuffer)
  memcpy(tmpBuffer, (msg.body.data())+OFFSET_SX, SIZE_SX);
  // Then copy the info from the tmpBuffer to the ublas_vector (tmpBuffer -> SX)
  copy(tmpBuffer, tmpBuffer+SX.size(), SX.data().begin());

  // get SX2
  //
  // First extract the data (msg -> tmpBuffer)
  memcpy(tmpBuffer, (msg.body.data())+OFFSET_SX2, SIZE_SX2);
  // Then copy the info from the tmpBuffer to the ublas_matrix (tmpBuffer -> SX2)
  copy(tmpBuffer, tmpBuffer+(SX2.size1()*SX2.size2()), SX2.data().begin());
}


void CompactStats(const ublas_vector &SX, const ublas_matrix &SX2, 
                  unsigned Nd, messageType &msg)
{
  //
  // Get the offsets for the fields in the message
  //
  
  const unsigned OFFSET_Nd=0;
  const unsigned SIZE_Nd=sizeof(unsigned);
  
  const unsigned OFFSET_SX=OFFSET_Nd+SIZE_Nd;
  const unsigned SIZE_SX=sizeof(double)*SX.size();
  
  const unsigned OFFSET_SX2=OFFSET_SX+SIZE_SX;
  const unsigned SIZE_SX2=sizeof(double)*SX2.size1()*SX2.size2();
  
  
  // just a temporary buffer where to copy the data extracted from 
  // the ublas types.
  double tmpBuffer[SIZE_SX2];
  
  //
  // construct the message and extract the data
  //
  
  // write the number of observations (Nd -> msg)
  memcpy(msg.body.data()+OFFSET_Nd, &Nd, SIZE_Nd);

  
  // write SX
  //
  // First copy the info from the ublas_vector to the tmpBuffer (SX -> tmpBuffer)
  copy(SX.data().begin(), SX.data().end(), tmpBuffer);
  // Then write the data (tmpBuffer -> msg)
  memcpy(msg.body.data()+OFFSET_SX, tmpBuffer, SIZE_SX);


  // write SX2
  //
  // First copy the info from the ublas_matrix to the tmpBuffer (SX2 -> tmpBuffer)
  copy(SX2.data().begin(), SX2.data().end(), tmpBuffer);
  // Then write the data (tmpBuffer -> msg)
  memcpy(msg.body.data()+OFFSET_SX2, tmpBuffer, SIZE_SX2);
}
