/* AUTORIGHTS
Copyright (C) 2008-2012 Marco Andreetto
      
This file is part of AB_SAMPLER.

AB_SAMPLER is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2, or (at your option)
any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software Foundation,
Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
*/

#ifndef _MY_PARALLEL_LIBRARY_
#define _MY_PARALLEL_LIBRARY_

#include <boost/asio.hpp>

#include <boost/numeric/ublas/matrix.hpp>
#include <boost/numeric/ublas/vector.hpp>


//
// Data structure for the messages that are exchanged between master and slave
//

// We want a message to have size 1024. We subtract the 2*sizeof(unsignd) for 
// the machineID and the message number in the sequence.
const unsigned M_LEN = 1024-2*sizeof(unsigned); 


struct messageType 
{
  unsigned machineID;
  unsigned seqNumber;
  
  boost::array<char, M_LEN> body;
};

const unsigned MSG_SIZE = sizeof(messageType); // This should be 1024 bytes.


// alias for a smart pointer to a tcp::socket. This will point to the socket 
// connections with the slaves
typedef boost::shared_ptr<boost::asio::ip::tcp::socket> socket_pr;

typedef boost::numeric::ublas::matrix<double> ublas_matrix;
typedef boost::numeric::ublas::vector<double> ublas_vector;

void ExtractStats(const messageType &, ublas_vector &, ublas_matrix &, unsigned &);
void CompactStats(const ublas_vector &, const ublas_matrix &, unsigned, messageType &);

#endif // _MY_PARALLEL_LIBRARY_
