function Cs_all=patch_gibbs_sampling_list_ext(Ws, alpha, NI, V_s, eta_s)

M=length(Ws);   % number of images in the collection
V=V_s{1};       % size of the dictionary of visual words
  

%% initial assignment of observations to clusters (Random)
Cs_all=cell(1, M);
Cs=cell(1, M);
thetas=cell(1, M);

% dimension of the model
K=length(alpha{1}); % number of topics

for m=1:M
  Cs{m}=unidrnd(K, length(Ws{m}), 1); % vector of assignment;
end

phi=sampleTopic(Cs, Ws, V, K, eta_s);

%% Run the sampler

S=length(NI); % number of samples to drawn

% start the sampling
for s=1:S % number of samples we want to generate
  
  tic;
  for h=1:NI(s) % number of iteration before generating the sample
    
    % since the topic distribution over visual words are not integrated out
    % we can sample images independently. 
    
    for m=1:M
      % sample image
      [Cs{m}, thetas{m}]=patch_sample_single_image(Ws{m}, Cs{m}, alpha{m}, phi);
      
    end
    
    % sample the topic distribution
    phi=sampleTopic(Cs, Ws, V, K, eta_s);
    
  end
  ttt=toc;
  
  Cs_all=compose_samples(Cs_all, Cs);
  disp(['Generated sample ', num2str(s), '/', num2str(S), ...
    ' in ', num2str(NI(s)), ' iter. Total time: ', num2str(ttt), ' sec.']);
end
disp('Sampling done');



function [C, theta]=patch_sample_single_image(W, C, alpha, phi)

% construct the indicator variables and the label counts
K=length(alpha);
N=rows(W);

U=labels2ind(C, K);
counts=sum(U);

% sample the new mixture coefficient for this image
theta=dirichlet_sample(alpha+counts, 1);

% (unnormalized) posterior
P=phi(W, :).*repmat(theta, N, 1);

% sample from P multinomial
C=sample_vector(P')';



function phi=sampleTopic(Cs, Ws, V, K, eta_s)

topic_counts=compTopicCounts(Ws, Cs, V, K);

phi=zeros(V, K);
for k=1:K
  phi(:, k)=dirichlet_sample(topic_counts(k, :)+eta_s{1})';
end



function Cs_all=compose_samples(Cs_all, Cs)

M=length(Cs_all);
if (M ~= length(Cs))
  error('Dimension mismatch for the number of samples');
end

for m=1:length(Cs)
  Cs_all{m}=[Cs_all{m}, Cs{m}];
end

% AUTORIGHTS
% Copyright (C) 2008-2012 Marco Andreetto
%       
% This file is part of AB_SAMPLER.
% 
% AB_SAMPLER is free software; you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation; either version 2, or (at your option)
% any later version.
% 
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
% 
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software Foundation,
% Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
