function pI=propSPValue(Val, Sp)

% pI=propSPValue(Val, Sp)
%
% given the superpixel segmentation 'Sp' and a set of value 'Val' return a
% new image 'pI' with all the pixels in a superpixel having the 
% corresponding value in 'Val'.

% total number of superpixels
nSp=max(max(Sp));

% check for consistency 
if (nSp ~= rows(Val))
  error('Mismatch between the number of value and the number of superpixels');
end
  
% dimension of the image
M=rows(Sp);
N=cols(Sp);

% total number of pixels
Np=M*N;

% number of values for each pixels
F=cols(Val);

% construct the pI
pI=zeros(M, N, F);
for h=1:nSp
  
  % all the pixels in superpixel h
  idx=find(Sp==h);
  
  % iterate over all the dimension of val
  for f=1:F
    
    % assign the current value to the supe pixels
    pI(idx)=Val(h, f);
    
    % move to the indeces of the next image plane of 'pI'
    idx=idx+Np;
  end
  
end

% AUTORIGHTS
% Copyright (C) 2008-2012 Marco Andreetto
%       
% This file is part of AB_SAMPLER.
% 
% AB_SAMPLER is free software; you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation; either version 2, or (at your option)
% any later version.
% 
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
% 
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software Foundation,
% Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
