function Sc=removeDust(S, K, T)
%REMOVEDUST
% Remove small disconnected components (dust) from the input segmentation
%
% Sc=removeDust(S, K, T)
%
% Given the segmentation mask 'S' remove small isolated regions that have
% an area smaller than 'T'. 'K' is the number of segments.
% 

M=rows(S);
N=cols(S);
cc=zeros(M, N);

% get all the connected components and give them different labels
for k=1:K
  Sk=(S==k);
  L=((bwlabel(Sk, 4)+1).*Sk);
  nc=max(max(cc));
  
  cc(Sk)=L(Sk)+nc+1;
end

% merge each small component to its larger neighbor.
cc=mergeSmallComp(cc, max(max(cc)), T);

% relabel the image to remove the unused labels.
labels=unique(cc(:));

tmp=zeros(M, N);
for l=1:length(labels)
  tmp(cc==labels(l))=l;
end
cc=tmp;
Kc=max(max(cc));

% iterate over all the connected components and label as the larger overlap
% segment.
Sc=ones(M, N);
for kc=1:Kc
  idx=(cc==kc);

  L=S(idx);
  counts=hist(L, 1:K);
  [~, l]=max(counts);
  
  Sc(idx)=l;
end

% AUTORIGHTS
% Copyright (C) 2008-2012 Marco Andreetto
%       
% This file is part of AB_SAMPLER.
% 
% AB_SAMPLER is free software; you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation; either version 2, or (at your option)
% any later version.
% 
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
% 
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software Foundation,
% Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
