function Cs_all_rm=removeSmallTopic(Cs_all, K, S)
%
% C_all_rm=removeSmallTopic(C_all, K, S)
%
%  For each segmentation remove the segment with smaller size. They are
%  replaced by random labels from the topics actually presents (sampled
%  uniformily not following the image distribution).
%
%  Cs_all is a cell array containing the segmentations
%
%  K is the total number of topics
%
%  S is the number of topics we keep in each image. By defualt is
%  round(K/3)
%
%  Cs_all_rm is the new assigments
%

% set defualt number of segments
if nargin<3, S=round(K/3); end


Cs_all_rm=cell(1, length(Cs_all));

% iterate over all the segmentation
for h=1:length(Cs_all)
  
  % extract the segmentation
  Cs=Cs_all{h};
  
  % compute the histogram
  th=hist(Cs, 1:K);
  [~, matching]=sort(th, 'descend');
  
  % separate the segment labels to keep and the one to reassign
  popular_topics=matching(1:S);
  unpopular_topics=matching((S+1):end);
 
  % get the points that needs to be reassigned.
  reassigned_idx=false(size(Cs));
  for l=1:length(unpopular_topics)
    reassigned_idx=reassigned_idx | Cs==unpopular_topics(l);
  end
  
  % reassign them.
  
  % random assignment for the points in the popular set
  reassigned_samples=unidrnd(S, rows(Cs), cols(Cs));
  reassigned_samples=remapLabels(reassigned_samples, [1:S; popular_topics]);
  Cs(reassigned_idx)=reassigned_samples(reassigned_idx);
  
  Cs_all_rm{h}=Cs;
end

% AUTORIGHTS
% Copyright (C) 2008-2012 Marco Andreetto
%       
% This file is part of AB_SAMPLER.
% 
% AB_SAMPLER is free software; you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation; either version 2, or (at your option)
% any later version.
% 
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
% 
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software Foundation,
% Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
