function [Cs, Cmap, P]=rwPropagateLabels(Cs_sel, imageFileName, affType)
% 
% myPropagation: propagates the labeling of the given grid points using the
% ab_gibbs_sampling.
% 
% Cs_sel: sample assignments for the selected points
%
% imageFileName

if (nargin<3)
  affType='ic';
end


%
% compute the MAP assignment for the labeling points
%
Cmap=extractMAP(Cs_sel); % MAP assignement fo the selected points
  

%
% construct the indeces of the points in the original set of observations
%
[W, ix, iy, scales]=loadPatchInfo(imageFileName);

if (length(W)~=length(Cmap))
  idx_scales=scales<20; % keep only the small scale features
else
  idx_scales=1:length(W);
end
c_idx=round(ix(idx_scales));
r_idx=round(iy(idx_scales));


%
% construct the fixed labels
%
I=imread(imageFileName);
image_row_num=rows(I);
image_col_num=cols(I);

idx=sub2ind([image_row_num, image_col_num], r_idx, c_idx);
si=zeros(image_row_num*image_col_num, 1);
si(idx)=Cmap;

% Number of segments in the image
K=max(si); 


%
% we need also the affinities and the observations for the whole image
% extract the image name without the path
%
[affFileName]=retriveDataFiles(imageFileName, affType);

% baseDirImages='/common/bart/core/work/databases/databases003/caltech4freeman130rows/';
% baseDirAff='/common/marco/clustering/datasets/Eugene/';
% fileName=imageFileName(length(baseDirImages):end);
% 
% switch (affType)
%   case 'lihi'
%     % filename for the affinities if we are using lihi method
%     affFileName=strcat(baseDirAff, fileName, '.R_11.mat');
% 
%   case 'ic'
%     % filename for the affinities if we are using Intervening countour
%     affFileName=strcat(baseDirAff, fileName, '.ic_aff.mat');
%     
%   otherwise
%     error('Unrecognize type of affinities');
% end

load(affFileName, 'A', 'X');
  

%
% Now we can run the technique of the random walk to compute a partition
%
N=rows(A);
P=zeros(rows(A), K); % matrix with all the potentials.

% preprocess the affinity matrix.
d=sum(A); % normalization of each node
D=sparse(1:N, 1:N, d); % construct a sparse diagonal matrix.
L=D-A; % if W is sparse then L should also be sparse


idx=(si==0); % get all the unlabled points

% get the value of all the nodes that are 
labels=si(si~=0);

Lu=L(idx, idx); % matrix Lu of the unmarked nodes
B=L(idx, ~idx);
gt=labels2ind(labels);

% potential at the non-fixed nodes
P(idx, 1:(K-1) ) = -Lu\( B*( gt(:, 1:(K-1)) ) );

% ground all the potentials
P(~idx, 1:(K-1))=0;  % set all the generator to zero
for k=1:(K-1), P(si==k, k)=1; end % set the potential to 1 for each labeled node

% fix small numerical error
P(P<0)=0;
P(P>1)=1-eps;

% set the potentials for the last label
P(:, K)=1-sum(P(:,1:(K-1)), 2);

% for k=1:(K-1)
%   
%   Prk=-Lu\(B*(labels==k));
%   Prk(Prk<0)=0;
%   Prk(Prk>1)=1-eps;
%   
%   P(idx, k)=Prk; % set the potentials
%   P(~idx, k)=0;  % set all the generator to zero
%   P(si==k, k)=1; % set all the points assigned to k to 1
% end
% 
%   
% % We set the last node simply as difference from 1 and
% % the sum of all the others.
% P(:, K)=1-sum(P(:,1:(K-1)), 2);


% finally we compute the hard assignment for this segmentation
[m, C]=max(P, [], 2); % rowmax

Cmap=C;
Cs=repmat(Cmap, 1, 5);

% AUTORIGHTS
% Copyright (C) 2008-2012 Marco Andreetto
%       
% This file is part of AB_SAMPLER.
% 
% AB_SAMPLER is free software; you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation; either version 2, or (at your option)
% any later version.
% 
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
% 
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software Foundation,
% Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
