function segCollectionTopic(xmlExpFile)
%
%
%
%

% load the experiment description and compute the segmentation statistcs.
expInfo=readXMLfile(xmlExpFile);

% get all the files with the segmentation
segFiles=getAllFilesInDir(expInfo.destDir, 'seg_map_*.mat');

% get the xmlFiles
NF=length(expInfo.data_file_info);
xmlFiles=cell(1, NF);
for h=1:NF
  xmlFiles{h}=expInfo.data_file_info{h}.xml_name;
end

% get statistics for the topics in the collection
[phi, theta]=compSegmentationStat(xmlFiles, segFiles, ...
                                  expInfo.dictionary_size, ...
                                  expInfo.K, ...
                                  expInfo.eta, ...
                                  expInfo.alpha);
% save /tmp/cache_res.mat phi theta;
% load /tmp/cache_res.mat phi theta;

% get the centers of the kmeans clusters
[centers, mu, L, vwInfo]=getVisualWordCenters('texture', ...
                                              'msrc', ...
                                              expInfo.dictionary_size, ...
                                              xmlFiles);
                                            
                                            

% iterate over all the images get the superpixels, compute a new assignment
% and save it in a new destination directory. 
expInfo.destDir=[expInfo.destDir(1:(end-1)), '_SP/'];
mkdir(expInfo.destDir);

for h=1:NF
  SP=xmlExtractSP(xmlFiles{h}, 0.1);
  
  [W, ix, iy]=xmlLoadPatchFilters(xmlFiles{h}, expInfo.grid_step, ...
                                  centers, mu, L);
  
  % get the maximum likelihood
  ll=spTopicResp(SP, ix, iy, W, phi, theta(h, :));
  [~, Cmap]=max(ll, [], 2);
  
  % expand the segmentation to the whole image
  segImageMAP=propSPValue(Cmap, SP);
  
  % save the segmentation mask in a new file
  save(sprintf('%s/seg_map_%04d.mat', expInfo.destDir, h), 'segImageMAP');

  putDot(h);
  
end

disp(' ');

% save a new xml for this 'fake' experiment
[~, name, ext] = fileparts(xmlExpFile);
saveXMLfile(expInfo, [name, '_SP.xml']);

% AUTORIGHTS
% Copyright (C) 2008-2012 Marco Andreetto
%       
% This file is part of AB_SAMPLER.
% 
% AB_SAMPLER is free software; you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation; either version 2, or (at your option)
% any later version.
% 
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
% 
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software Foundation,
% Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
