function map=seg_color(nSeg, useGB)
%
% map=seg_color(nSeg, useGB) returns a color map to visualize segmentation
% results.
%
% nSeg: number of segments, and number of rows of the color map. If it is
% bigger than 11 then the colorcube function is used
%
% useGB: force the first segment to be black (garbage collector)
%

% default to background cluster
if nargin<2, useGB=0; end


% construct the color map for 11 segments
map=[
     255 255   0; % full yellow
     255   0   0; % full red
     0   255   0; % full green;
     0     0 255; % full blue
     255   0 255; % magenta
     0   255 255; % cyan
     126 100 172; % violet
     255 110   0; % orange
      63 128  63; % dark green
     195 195 195; % light gray
      87  87  87; % dark gray
     ];
map=map/255;  

if nSeg>rows(map)  
  map=colorcube(nSeg);
else
  map=map(1:nSeg, :);
end

% set the garbage collector cluster to zero if present
if useGB, 
  map=cat(1, [0.5 0.5 0.5], map(1:(end-1), :)); 
end

% AUTORIGHTS
% Copyright (C) 2008-2012 Marco Andreetto
%       
% This file is part of AB_SAMPLER.
% 
% AB_SAMPLER is free software; you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation; either version 2, or (at your option)
% any later version.
% 
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
% 
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software Foundation,
% Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
