/* AUTORIGHTS
Copyright (C) 2008-2012 Marco Andreetto
      
This file is part of AB_SAMPLER.

AB_SAMPLER is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2, or (at your option)
any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software Foundation,
Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
*/

#include <iostream>
#include <vector>
#include <iterator>
#include <algorithm>
#include <functional>

#include "mex.h"

#define iR (in[0])
#define iW (in[1])
#define iV (in[2])

#define oB (out[0])


using namespace std;

struct mat2cpp : public unary_function<unsigned, double> {
    unsigned operator()(double x) { return (static_cast<unsigned>(x)-1); }
};



//
// The inputs are the responsability matrix R and the word vector W
//


void mexFunction(int n_out, mxArray *out[],
                 int n_in, const mxArray *in[])
{ 
  //
  // Check the inputs and the output arguments   
  //
  
  if (n_in!=3)
    mexErrMsgTxt("Three inputs required");
  
  if (n_out!=1)
    mexErrMsgTxt("One output required");
  
  // first we check for compatible dimension
  unsigned N=mxGetM(iR);
  if (mxGetM(iR)!=mxGetM(iW))
    mexErrMsgTxt("Incompatible dimensions");
  
  // get the number of topics
  unsigned K=mxGetN(iR);
  if (K<=1) 
    mexErrMsgTxt("The responsibility matrix R should have at least 2 columns");
  
  // number of words in the dictionary
  unsigned V=static_cast<unsigned>(mxGetScalar(iV)); 

  // create a vector of unsigned to store the visual words (after subtructing 
  // 1) this is to have the visual words in Cpp format always available.
  vector<unsigned> W(N);
  transform(mxGetPr(iW), mxGetPr(iW)+N, W.begin(), mat2cpp());
  
  // check that the all the words are smaller than V
  if (find_if(W.begin(), W.end(), 
       bind2nd(greater_equal<unsigned>(), V)) != W.end())
    mexErrMsgTxt("Unrecognized visual words");  
  
  // allocate the output
  oB=mxCreateDoubleMatrix(K, V, mxREAL);
  fill(mxGetPr(oB), mxGetPr(oB)+(K*V), 0.0);
  
  
  // pointer to the mxArrays
  double *pB=mxGetPr(oB);
  vector<unsigned>::iterator pW; 

  // iterate over all the topics
  for(unsigned k=0; k<K; ++k){
    double *pR=mxGetPr(iR)+k*N; // pointer to the k-th column of the 
                                // responsability matrix
    for(pW=W.begin(); pW!=W.end(); ++pW, ++pR){
      pB[(*pW)*K+k]+=(*pR);
    }
  }
}
