/* AUTORIGHTS
Copyright (C) 2008-2012 Marco Andreetto
      
This file is part of AB_SAMPLER.

AB_SAMPLER is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2, or (at your option)
any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software Foundation,
Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
*/

#ifndef __TABLE_H__
#define __TABLE_H__

#include <iostream>
#include <fstream>
#include <vector>


template <typename T>
class table
{
  typedef T* iterator;
  typedef const T* const_iterator;

  friend std::ostream &operator<<(std::ostream &os, const table<T> t) { 
    //os<<t.m<<" "<<t.n<<std::endl;
    for(unsigned i=0; i<t.m; ++i) {
      for(unsigned j=0; j<t.n; ++j)
        os<<t.data[i*t.n+j]<<" ";
      os<<std::endl;
    }
    return os;
  }

  friend std::istream &operator>>(std::istream &is, table<T> t) { 
    //is>>t.m>>t.n;
    for(unsigned i=0; i<t.m; ++i)
      for(unsigned j=0; j<t.n; ++j)
        is>>t.data[i*t.n+j];

    return is;
  }
  
  std::vector<T> data; // contains all the data in the table (row-wise)
  unsigned m;  // number of rows
  unsigned n;  // number of columns
   
  public:
  table() : data() { m=0; n=0; }
  table(unsigned im, unsigned in) : data(im*in, 0) { m=im; n=in; }
  
  void resize(unsigned im, unsigned in) 
  { data.clear(); data.resize(im*in, 0); m=im; n=in; }
  
  void resize(unsigned im, unsigned in, T defValue)
  { data.clear(); data.resize(im*in, defValue); m=im; n=in; }
  
  unsigned NumberOfRows() const { return m; }
  unsigned NumberOfCols() const { return n; }
  
  const T& operator()(unsigned i, unsigned j) const
  { assert((i>=0) && (i<m)); assert((j>=0) && (j<n)); return data[i*n+j]; }
  
  T& operator()(unsigned i, unsigned j)
  { assert((i>=0) && (i<m)); assert((j>=0) && (j<n)); return data[i*n+j]; }
  
  iterator begin() { return data.begin(); }
  const_iterator begin() const { return data.begin(); }
  
  iterator end() { return data.begin(); }
  const_iterator end() const { return data.begin(); }
  
  
  void ReadTable(const char *inFileName) const
  {
    std::ifstream inFile(inFileName, std::ios::in);
    if (!inFile) {
      std::cerr<<"Unable to open file "<<inFileName<<std::endl;
      exit(-1);
    }
  
    inFile>>*this;
  }

  void SaveTable(const char *outFileName) const
  {
    std::ofstream outFile(outFileName, std::ios::out);
    if (!outFile) {
      std::cerr<<"Unable to open file "<<outFileName<<std::endl;
      exit(-1);
    }
  
    outFile<<*this<<std::endl;
  }
  
  ~table() { }
};


#endif
