function windows_install(action)

%
% WINDOWS_INSTALL
%
%  Generates the mex files for AB_SAMPLER. Microsoft Visual Studio 8.0 and
%  the Boost library 1.35.0 are required. Follow the instructions at the 
%  Boost website to install boost on your system:
%  http://www.boost.org/doc/libs/1_37_0/more/getting_started/windows.html
%  Modify the value of the variable BOOST_INCLUDE_PATH if necessary
%

% Defaul action is 'install'
if nargin<1, action='install'; end  

switch lower(action)
  
  case 'install'
    % path for the include files of the boost library.
    BOOST_INCLUDE_PATH='c:\PROGRA~1\boost\boost_1_37\';

    % create the mex files for the recognition/segmentation system
    fprintf('Creating ab_gibbs_sampling.mexw32...');
    eval(['mex -I', BOOST_INCLUDE_PATH, ...
        ' -output ab_gibbs_sampling.mexw32 ', ...
        ' ab_log.cpp ab_gibbs_sampling.cpp ab_sampler.cpp ', ...
        ' my_distributions.cpp']);
    fprintf('done\n');

    fprintf('Creating ab_gibbs_sampling_list.mexw32...');
    eval(['mex -I', BOOST_INCLUDE_PATH, ...
        ' -output ab_gibbs_sampling_list.mexw32 ', ...
        ' ab_log.cpp ab_gibbs_sampling_list.cpp ab_sampler.cpp ', ...
        ' my_distributions.cpp ab_sampler_list.cpp']);
    fprintf('done\n');

    fprintf('Creating ab_gibbs_sampling_list_sharing.mexw32...');
    eval(['mex -D_SHARE_PARAM_ -I', BOOST_INCLUDE_PATH, ...
        ' -output ab_gibbs_sampling_list_sharing.mexw32 ', ...
      ' ab_gibbs_sampling_list.cpp ab_sampler.cpp ', ...
      ' my_distributions.cpp ab_log.cpp ab_sampler_list.cpp ']);
    fprintf('done\n');

    fprintf('Creating patch_gibbs_sampling.mexw32...');
    eval(['mex -D_PATCHES_ONLY_ -I', BOOST_INCLUDE_PATH, ...
        ' -output patch_gibbs_sampling_list.mexw32 ', ...
      ' ab_gibbs_sampling_list.cpp ab_sampler.cpp ', ...
      ' my_distributions.cpp ab_log.cpp ab_sampler_list.cpp ']);
    fprintf('done\n');

    fprintf('Creating scale_dist.mexw32...');
    mex scale_dist.cpp;
    fprintf('done\n');

    fprintf('Creating sumTopicResp.mexw32...');
    mex sumTopicResp.cpp;
    fprintf('done\n');

    fprintf('Creating compTopicCounts.mexw32...');
    mex compTopicCounts.cpp;
    fprintf('done\n');

    
  case 'clean'
    % remove all the mex files
    warning('off', 'MATLAB:DELETE:FileNotFound');
    eval(['delete ab_gibbs_sampling.mexw32 ', ...
          'patch_gibbs_sampling_list.mexw32 ', ...
          'ab_gibbs_sampling_list.mexw32 ', ...
          'ab_gibbs_sampling_list_sharing.mexw32 ', ...
          'scale_dist.mexw32 ', ...
          'sumTopicResp.mexw32']);
    warning('on', 'MATLAB:DELETE:FileNotFound');
    
        
  otherwise
    error('Unrecognized action');
    
end

% AUTORIGHTS
% Copyright (C) 2008-2012 Marco Andreetto
%       
% This file is part of AB_SAMPLER.
% 
% AB_SAMPLER is free software; you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation; either version 2, or (at your option)
% any later version.
% 
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
% 
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software Foundation,
% Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
