function [cf_table, datasetName]=xmlComputeErrors(xmlFile, selected_idx)

% Compute the confusion table between the topic segmentation and gt
% segmentation. At the moment it works only for the MSRC v1 dataset. 
% The confusion table has as many rows as the topics and many columns 
% as the object classes.
% The entry i,j contains the number of pixels assigned to topic i and
% marked as belonging to class j.


disp('Compute confusion table');

% load the info fo rthe experiment
expInfo=readXMLfile(xmlFile);

% get the name of the dataset used in the experiment. We get the name from
% the first data file.
datasetName=expInfo.data_file_info{1}.datasetName;

% get all the files with the topics. These files should be in
% coerrespondence with the files in 'expInfo.data_file_info'.
resFile=getAllFilesInDir(expInfo.destDir, 'seg_map_*.mat');
% resFile=getAllFilesInDir(expInfo.destDir, 'seg_fern*.mat');

if isempty(resFile)
  % we do not have any segmentation file. Try to generate them
  disp('Missing segmentation files. Try to generate them');
  xmlGenerateSegmentations(xmlFile);
  % xmlGenerateSegmentationsSP(xmlFile);
  resFile=getAllFilesInDir(expInfo.destDir, 'seg_map*.mat');
else
  % check if the creation date for the segmentation precedes the creation
  % date for the file with all the results.
  segFileStat=dir(resFile{1});
  resFileStat=dir([expInfo.destDir, '/seg_results.mat']);
  
  if (segFileStat.datenum<resFileStat.datenum)
    disp('Old segmentation files. Try to regenerate them');
    xmlGenerateSegmentationsSP(xmlFile);
    % xmlGenerateSegmentationsSP(xmlFile);
    resFile=getAllFilesInDir(expInfo.destDir, 'seg_map*.mat');
  end
end
  

% check if there is any inconsistency 
if (length(expInfo.data_file_info)~=length(resFile))
  error('Different number of files');
end

% is we are using a subset we need to select only a subset for computing
% the confusion table.
% if use
if nargin == 2
  resFile=resFile(selected_idx);
  expInfo.data_file_info=expInfo.data_file_info(selected_idx);
end

% this is the confusion table
cf_table=zeros(expInfo.K, 1);

for h=1:length(resFile)
  load(resFile{h}, 'segImageMAP');
  load(expInfo.data_file_info{h}.ground_truth_name, 'gt_seg');
    
  for k=1:expInfo.K
    for l=1:max(max(gt_seg))
      
      % how many pixels are in agreement between topic k and class l for
      % the current image.
      a=sum(sum((segImageMAP==k) & (gt_seg==l)));
      
      if l>cols(cf_table)
        cf_table(k,l)=a;
      else
        cf_table(k, l)=cf_table(k, l)+a; % add at the confusion table
      end
    end
    
  end
  
  putDot(h);
end
disp(' ');


disp(' ');

% AUTORIGHTS
% Copyright (C) 2008-2012 Marco Andreetto
%       
% This file is part of AB_SAMPLER.
% 
% AB_SAMPLER is free software; you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation; either version 2, or (at your option)
% any later version.
% 
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
% 
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software Foundation,
% Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
