function [sp, A, cx, cy]=xmlExtractSP(xmlFileName, T)
%
% Extract the superpixels for an image using the ucm map
%

if nargin==1, T=0.02; end;

% structure with all the information
imageInfo=xml_load(xmlFileName);

% the boolean function 'compute_superpixels' checks if we have to recompute
% the superpixels or if we can use the cached values.
if compute_superpixels(imageInfo, 'superpixels_name', T)
  
  % we assume that we have the ultrametric contour map available.
  load(imageInfo.ucm_affinities_name, 'Contours');
  [sp, A, cx, cy]=ucm2Superpixels(Contours, T);
  
  % save the superpixels file
  imageInfo.superpixels_name=[imageInfo.original_name, '.superpixels.mat'];
  save(imageInfo.superpixels_name, 'sp', 'A', 'cx', 'cy');
  imageInfo.superpixel_date=getFileDate(imageInfo.superpixels_name);
  
  % save the update xml file for the cached values
  xml_save(imageInfo.xml_name, imageInfo);
  
end

% we load the superpixels
load(imageInfo.superpixels_name, 'sp', 'A', 'cx', 'cy');



function comp_sp=compute_superpixels(imageInfo, field_name, iT)

% check if we need to compute the data, either because we do not have the
% field in the XML file or because we have the 'forceComp' flag.
comp_sp=~isfield(imageInfo, field_name);

% even if we do not have to recompute the superpixels it may be the case
% that the file does not exist. We also check for this case.
comp_sp=comp_sp || ~exist(eval(['imageInfo.', field_name]), 'file');

% AUTORIGHTS
% Copyright (C) 2008-2012 Marco Andreetto
%       
% This file is part of AB_SAMPLER.
% 
% AB_SAMPLER is free software; you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation; either version 2, or (at your option)
% any later version.
% 
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
% 
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software Foundation,
% Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
