function [W, ix, iy, R]=xmlLoadPatchGaborFilters(xmlFile, step, texture_words, mu, L, recompute)
%
% Load the filter bank responce and compute the quatized visual words for
% the specified grid. The '2' version uses a different type of filters:
% gabor filters and the laplacian at two scale.
%
% if recompute is set to true then the filter bank responce is recompute
%
if nargin<4, mu=[]; end
if nargin<6, recompute=false; end

% load the xmlFile
imageInfo=xml_load(xmlFile);

% generate the grid positions
[ix, iy, ix_rng, iy_rng]=getGridPositions(imageInfo.width, imageInfo.height, step);

% get the filter bank response
G=loadGaborFilterBankResponse(imageInfo, recompute);

% extract all the fileters we need
R=reshape(G(iy_rng, ix_rng, :), [length(ix), size(G, 3)]);

if ~isempty(mu)
  % normalize the points in space if necessary
  R=R-repmat(mu, rows(R), 1);
  R=(inv(L')*R')';
end

% compute the visual words labels
[d, W]=mindist(texture_words', R');
W=W(:);


function G=loadGaborFilterBankResponse(imageInfo, recompute)

% check if the filter back response is already available, if not compute it
% and save it. 

filter_bank_file=[imageInfo.original_name, '.filter2.mat'];

if (~exist(filter_bank_file, 'file') || recompute)
  
  % there is no field 'filter_bank_name', or we are forced to recompute it.
  imageInfo.filter_bank_name=filter_bank_file;
  
  % create the filter output of the given image
  I=im2double(imread(imageInfo.original_name));
  disp('Computing filter bank');
  disp(imageInfo.original_name);

  G=getResponseGaborFilterBank(I);
  
  % save the filter bank response
  save(imageInfo.filter_bank_name, 'G');
  
  % updated xmlFile
  imageInfo.filter_bank_date=getFileDate(imageInfo.filter_bank_name);
  xml_save(imageInfo.xml_name, imageInfo);
else
  load(imageInfo.filter_bank_name, 'G');
end

% AUTORIGHTS
% Copyright (C) 2008-2012 Marco Andreetto
%       
% This file is part of AB_SAMPLER.
% 
% AB_SAMPLER is free software; you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation; either version 2, or (at your option)
% any later version.
% 
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
% 
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software Foundation,
% Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
