function cf_table=xmlMakeConfTable(xmlFile, selected_idx)

% Compute the confusion table between the class labels segmentation and gt
% segmentation.

disp('Compute confusion table');

% load the info fo rthe experiment
expInfo=readXMLfile(xmlFile);

% get the name of the dataset used in the experiment. We get the name from
% the first data file.
datasetName=expInfo.data_file_info{1}.datasetName;

% get all the files with the topics. These files should be in
% coerrespondence with the files in 'expInfo.data_file_info'.
resFile=getAllFilesInDir(expInfo.destDir, 'seg_class*.mat');

% check if there is any inconsistency 
if (length(expInfo.data_file_info)~=length(resFile))
  error('Different number of files');
end

resFile=resFile(selected_idx);
expInfo.data_file_info=expInfo.data_file_info(selected_idx);

% this is the confusion table
cf_table=zeros(expInfo.K, 1);

for h=1:length(resFile)
  load(resFile{h}, 'segImageMAP');
  load(expInfo.data_file_info{h}.ground_truth_name, 'gt_seg');
    
  for k=1:expInfo.K
    for l=1:max(max(gt_seg))
      
      % how many pixels are in agreement between topic k and class l for
      % the current image.
      a=sum(sum((segImageMAP==k) & (gt_seg==l)));
      
      if l>cols(cf_table)
        cf_table(k,l)=a;
      else
        cf_table(k, l)=cf_table(k, l)+a; % add at the confusion table
      end
    end
    
  end
  
  putDot(h);
end
disp(' ');
disp(' ');

% AUTORIGHTS
% Copyright (C) 2008-2012 Marco Andreetto
%       
% This file is part of AB_SAMPLER.
% 
% AB_SAMPLER is free software; you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation; either version 2, or (at your option)
% any later version.
% 
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
% 
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software Foundation,
% Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
