function xmlMakeProbTopicPanel(xmlFile, k, M, N)
% 
% Construct a set of panels with the segments in the images for topic 'k'.
% M and N are the number of rows and column in the panel. 
% 

% If not specified the scale parameter is fixed to 4.
if (nargin<5), scale=1; end

% info about the experiment
expInfo=readXMLfile(xmlFile);

% iterate over all the image and extract the segments
L=length(expInfo.data_file_info);
segFiles=getAllFilesInDir(expInfo.destDir, 'seg_map_*.mat');

seg_list=cell(1, L);
seg_sizes=zeros(1, L);

for h=1:L
  [~, seg_sizes(h), seg_list{h}]=xmlShowProbTopic(k, h, expInfo.data_file_info, ...
                                         segFiles);
  putDot(h);
end
disp(' ');

% sort the selected images by size if we have less slot than images
if (M*N)<L
  [~, idx]=sort(seg_sizes, 'descend');
  seg_list=seg_list(idx);
  
  pause;
end

% identifier for the figure containing the segments
segFigID=330+k;
origFigID=430+k;

% display all the images into a single panel
figure(segFigID); clf; % figure for the segment pannel

for t=1:min(L, (M*N))
  % plot the segments 
  figure(segFigID); vl_tightsubplot(M, N, t); imshow(seg_list{t});
end


% AUTORIGHTS
% Copyright (C) 2008-2012 Marco Andreetto
%       
% This file is part of AB_SAMPLER.
% 
% AB_SAMPLER is free software; you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation; either version 2, or (at your option)
% any later version.
% 
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
% 
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software Foundation,
% Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
