function [pannel_seg, seg_sizes]=xmlMakeTopicPanel(xmlFile, k, ...
                                                  M, N, scale, ...
                                                  fileNameSeg, fileNameOrig)
% 
% Construct a set of panels with the segments in the images for topic 'k'.
% M and N are the number of rows and column in the panel. The images are
% downsamples by 'scale'. 

% If not specified the scale parameter is fixed to 4.
if (nargin<5), scale=1; end

load('/home/marco/research/projects/AB_Clustering/testing/msrcGT.mat', ...
  'class_labels');
idx=[1 2 3 6 7 8 10 11 12 13 14];
class_labels=class_labels(idx); %#ok<NODEF>

disp(['Segments for ', class_labels{k}, ' category']);

% info about the experiment
expInfo=readXMLfile(xmlFile);

% iterate over all the image and extract the segments
L=length(expInfo.data_file_info);
segFiles=getAllFilesInDir(expInfo.destDir, 'seg_class_*.mat');

seg_list=cell(1, L);
orig_list=cell(1, L);
seg_sizes=zeros(1, L);

% blank color
blank_color=cat(3, 0, 1, 1); % this is cyan

for h=1:L
  % load the image
  I=im2double(imread(expInfo.data_file_info{h}.original_name));
  I=imresize(I, 1./scale, 'bilinear');
  
%   % create a "RGB" "gray scale" image
%   I=rgb2gray(I);
%   I=cat(3, I, I, I);
  
  % load the segmentation
  load(segFiles{h}, 'segImageMAP');
  segImageMAP=imresize(segImageMAP, [rows(I), cols(I)], 'nearest');
  
%   % load the ground truth
%   load(expInfo.data_file_info{h}.ground_truth_name, 'gt_seg');
%   gt_seg=imresize(gt_seg, [rows(I), cols(I)], 'nearest');
    
  % get the size for the correctly labeled regions of this image
  s=sum(sum( (segImageMAP==k)  ));
  
  % compute the area of overal
  seg_sizes(h)=s;
  seg_list{h}=getSegment(I, segImageMAP==k, blank_color);
  orig_list{h}=segImage(I, segImageMAP);
  
  putDot(h);
end
disp(' ');

% sort the selected images by size if we have less slot than images
if (M*N)<L
  [seg_sizes, idx]=sort(seg_sizes, 'descend');
  seg_list=seg_list(idx);
  orig_list=orig_list(idx);
end

% identifier for the figure containing the segments
segFigID=100+30+k;
origFigID=100+130+k;

% display all the images into a single panel
figure(segFigID); clf; % figure for the segment pannel

for t=1:min(L, (M*N))
  % plot the segments 
  figure(segFigID); vl_tightsubplot(M, N, t); imshow(seg_list{t});    
end

% save the panel into a file and pass it as output.
if (nargin<6)
  saveas(segFigID, 'tmp_pannel.png');
  pannel_seg=imread('tmp_pannel.png');
  delete('tmp_pannel.png');

%   saveas(origFigID, 'tmp_pannel_orig.png');
%   pannel_orig=imread('tmp_pannel_orig.png');
%   delete('tmp_pannel_orig.png');
else
  saveas(segFigID, fileNameSeg);
  pannel_seg=imread(fileNameSeg);

%   saveas(origFigID, fileNameOrig);
%   pannel_orig=imread(fileNameOrig);
end  


function segment=getSegment(I, idx, blank_color)

segment=zeros(rows(I), cols(I), 3);

% just in case we are using gray scale pictures.
if size(I)==1, I=cat(3, I, I, I); end
  
for c=1:3
  plane=I(:,:,c);
  plane(~idx)=blank_color(1, 1, c);
  segment(:,:,c)=plane;
end

% AUTORIGHTS
% Copyright (C) 2008-2012 Marco Andreetto
%       
% This file is part of AB_SAMPLER.
% 
% AB_SAMPLER is free software; you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation; either version 2, or (at your option)
% any later version.
% 
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
% 
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software Foundation,
% Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
