function [errors, ct, mapping]=xmlPrepareAllResults(xmlFile)

% if nargin==1, legendItems={'Old', 'Curr.', 'Wang et al.'}; end

% compute the topic class confusion table
[ct, datasetName]=xmlComputeErrors(xmlFile);

% with this information we compute the labeling and the classification
% errors for the MSRC dataset. We use 3 as the maximum number of
% topics/segments for each class.

% =========================================================================
switch (datasetName) 
  case 'MSRCv1'
    % best mapping of one topic in one category
    [errors_1, m1]=analyze_error_MSRCv1(ct, 1);
    
    % "best" mapping of two topics in one category
    [errors_2, m2, class_labels]=analyze_error_MSRCv1(ct, 3);
    
    % the current errors are refers to one topic one category
    errors=errors_1; 
    
  case 'MSRCv2'
    % best mapping of one topic in one category
    [errors_1, m1]=analyze_error_MSRCv2(ct, 1); 

    % "best" mapping of two topics in one category
    [errors_2, m2, class_labels]=analyze_error_MSRCv2(ct, 3);
    errors=errors_1;
    
  otherwise
    error('Unrecognized dataset');
end

% this is to verify.
for l=3:rows(errors)
  F1=errors_1{l, end};
  F2=errors_2{l, end};
  
  if (F2>F1)
    errors(l, :)=errors_2(l, :);
  else
    m2(2, l-2)=0;
    
    if m1(l-2) ~= m2(1, l-2)
      disp('Something wrong in the matching process');
    end
  end
end
mapping=m2;

% construct an inverse index between topics and categories
nc=cols(mapping);
im=zeros(1, 20);
for k=1:length(im)
  [~, j]=find(mapping==k);
  if ~isempty(j), im(k)=j; end
end
im=im+1;
disp(['Inverse mapping: ', num2str(im)]);

disp('Mapping categories to topics');
for l=1:cols(mapping)
  str=sprintf('%10s : %4d', class_labels{l+1}, mapping(1, l));
  if (mapping(2, l)~=0)
    str=sprintf('%s %4d', str, mapping(2, l));
  end
  disp(str);
end
disp(' ');

% with the (single topic) mapping we can relabel the segmentations
xmlRelabelSegmentations(xmlFile, mapping);

% ct=xmlMakeConfTable(xmlFile, 2:2:240);
% ct=ct(1:cols(ct), :);

% % we compute also the average color for each segment
% colors=xmlCompAverageSegColors(xmlFile);

% we produce images for the HTML page with the results
showFigures=false;

% % segments 
% disp('Color for the seg maps');
% colorSegmentations(xmlFile, 'seg_map_0*.mat', 'standard', showFigures);

% % colors
% disp('Average color segmentation');
% colorSegmentations(xmlFile, 'seg_map_0*.mat', colors, ...
%                    showFigures, 'seg_colors');
% 
% % segment boundaries
% close all;
% disp('Boundaries of the segments');
% boundarySegmentations(xmlFile, 'seg_map_0*.mat', true, 'seg_bound');

showFigures=false;

% colors
disp('Colors for the class labels');
colorSegmentations(xmlFile, 'seg_class_0*.mat', 'class', showFigures);

% % save also the topic pannels
% close all;
% fn={'clutter', 'cows', 'grass', 'cars', 'sky', ...
%     'foliage', 'sea', 'bikes', 'faces'};
% 
% for k=1:length(fn)
%   disp([fn{k}, ' pannel']);
%   pannel=xmlMakeTopicPanel(xmlFile, k, 10, 12); 
%   imwrite(pannel, [fn{k}, '.png']);
%   disp(' ');
% end


% save the ct the errors and the topic/class mapping into the file with 
% all the results.
disp('Save the error data');
s=readXMLfile(xmlFile);
disp(' ');

class_errors=cell2mat(errors(3:end, 2:3));   %#ok<NASGU>
save([s.destDir, '/additional_seg_results.mat'], ...
  'ct', 'errors', 'mapping', 'im', 'class_errors');

% % prepare the performance plot for these experiment
% % load the errors from the results file.
% load([s.destDir, '/seg_results.mat'], 'ct', 'errors', 'mapping', 'class_errors');
% 
% % load the journal version errors
% load(['/home/marco/research/papers/clustering/ab_clustering/Journal/Figures/', ...
%   'texture_error_results_for_papers.mat'], 'errors_total');
% errors=errors_total;
% 
% % labels
% labels=errors(3:end, 1);
% errors=cell2mat(errors(3:end, 2:3));
% 
% % get the experiment tag
% tag=getExperimentTag(s);
% 
% figure(31); clf;
% make_performance_plot('arrow', false, 'labels', labels, ...
%                       'legend', true', ...
%                       'outfile', ['PerfComp-', tag, '.png'], ...
%                       errors_pocv, '+b', legendItems{1}, ...
%                       errors_curr, 'or', legendItems{2}, ...
%                       errors_wang_grimson, 'dk', legendItems{3});
% 
% figure(37); clf;
% make_performance_plot('arrow', true, ...
%                       'outfile', ['PerfComp-', tag, '-arrow.png'], ...
%                       errors_pocv, '.k', '', ...
%                       errors_curr, 'ok', '');
% 
% 
% function tag=getExperimentTag(s)
% 
% d=s.destDir;
% if d(end)=='/', d=d(1:end-1); end
% tag=d(strfind(d, '200'):end);


% AUTORIGHTS
% Copyright (C) 2008-2012 Marco Andreetto
%       
% This file is part of AB_SAMPLER.
% 
% AB_SAMPLER is free software; you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation; either version 2, or (at your option)
% any later version.
% 
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
% 
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software Foundation,
% Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
