function xmlRelabelSegmentations(xmlFile, mapping)

%
% relabel the segmentations of 'xmlFile' according to the mapping 
% specified in 'mapping'.
%

disp('Reassigne the segmentation labels');

% load the file structure with all the info about the experiment
expInfo=readXMLfile(xmlFile);

% load the segmentations: both matlab and png
segFiles=getAllFilesInDir(expInfo.destDir, 'seg_map_*.mat');

% iterate over all the files used in this experiment and generate and
% generate the segmentation images
for h=1:length(segFiles)
  
  % load the segmentation 
  load(segFiles{h}, 'segImageMAP');
  
  % relabel it. The label 1 correspond to the background
  segImageMAP=relabel(segImageMAP, mapping); 
  
  % save the new segmentation in the class file
  matFileName=sprintf('%s/seg_class_%04d.mat', expInfo.destDir, h);
  save(matFileName, 'segImageMAP');
  
  putDot(h);
end
disp(' ');

disp(' ');


function segImageMAP_new=relabel(segImageMAP, mapping)

segImageMAP_new=zeros(size(segImageMAP));
for h=1:cols(mapping)
  idx=(segImageMAP==mapping(1, h));
  for k=2:rows(mapping)
    idx=idx | (segImageMAP==mapping(k, h));
  end
  segImageMAP_new(idx)=h;
end

segImageMAP_new=segImageMAP_new+1;

% AUTORIGHTS
% Copyright (C) 2008-2012 Marco Andreetto
%       
% This file is part of AB_SAMPLER.
% 
% AB_SAMPLER is free software; you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation; either version 2, or (at your option)
% any later version.
% 
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
% 
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software Foundation,
% Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
